/* Generated by ./src/xlat/gen.sh from ./src/xlat/packet_diag_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat packet_diag_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data packet_diag_attrs_xdata[] = {
 [PACKET_DIAG_INFO] = XLAT(PACKET_DIAG_INFO),
 #define XLAT_VAL_0 ((unsigned) (PACKET_DIAG_INFO))
 #define XLAT_STR_0 STRINGIFY(PACKET_DIAG_INFO)
 [PACKET_DIAG_MCLIST] = XLAT(PACKET_DIAG_MCLIST),
 #define XLAT_VAL_1 ((unsigned) (PACKET_DIAG_MCLIST))
 #define XLAT_STR_1 STRINGIFY(PACKET_DIAG_MCLIST)
 [PACKET_DIAG_RX_RING] = XLAT(PACKET_DIAG_RX_RING),
 #define XLAT_VAL_2 ((unsigned) (PACKET_DIAG_RX_RING))
 #define XLAT_STR_2 STRINGIFY(PACKET_DIAG_RX_RING)
 [PACKET_DIAG_TX_RING] = XLAT(PACKET_DIAG_TX_RING),
 #define XLAT_VAL_3 ((unsigned) (PACKET_DIAG_TX_RING))
 #define XLAT_STR_3 STRINGIFY(PACKET_DIAG_TX_RING)
 [PACKET_DIAG_FANOUT] = XLAT(PACKET_DIAG_FANOUT),
 #define XLAT_VAL_4 ((unsigned) (PACKET_DIAG_FANOUT))
 #define XLAT_STR_4 STRINGIFY(PACKET_DIAG_FANOUT)
 [PACKET_DIAG_UID] = XLAT(PACKET_DIAG_UID),
 #define XLAT_VAL_5 ((unsigned) (PACKET_DIAG_UID))
 #define XLAT_STR_5 STRINGIFY(PACKET_DIAG_UID)
 [PACKET_DIAG_MEMINFO] = XLAT(PACKET_DIAG_MEMINFO),
 #define XLAT_VAL_6 ((unsigned) (PACKET_DIAG_MEMINFO))
 #define XLAT_STR_6 STRINGIFY(PACKET_DIAG_MEMINFO)
 [PACKET_DIAG_FILTER] = XLAT(PACKET_DIAG_FILTER),
 #define XLAT_VAL_7 ((unsigned) (PACKET_DIAG_FILTER))
 #define XLAT_STR_7 STRINGIFY(PACKET_DIAG_FILTER)
};
static
const struct xlat packet_diag_attrs[1] = { {
 .data = packet_diag_attrs_xdata,
 .size = ARRAY_SIZE(packet_diag_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
