/* Generated by ./src/xlat/gen.sh from ./src/xlat/bpf_attach_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(BPF_F_ALLOW_OVERRIDE) || (defined(HAVE_DECL_BPF_F_ALLOW_OVERRIDE) && HAVE_DECL_BPF_F_ALLOW_OVERRIDE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_ALLOW_OVERRIDE) == (1U), "BPF_F_ALLOW_OVERRIDE != 1U");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_ALLOW_OVERRIDE 1U
#endif
#if defined(BPF_F_ALLOW_MULTI) || (defined(HAVE_DECL_BPF_F_ALLOW_MULTI) && HAVE_DECL_BPF_F_ALLOW_MULTI)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_ALLOW_MULTI) == ((1U << 1)), "BPF_F_ALLOW_MULTI != (1U << 1)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_ALLOW_MULTI (1U << 1)
#endif
#if defined(BPF_F_REPLACE) || (defined(HAVE_DECL_BPF_F_REPLACE) && HAVE_DECL_BPF_F_REPLACE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_REPLACE) == ((1U << 2)), "BPF_F_REPLACE != (1U << 2)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_REPLACE (1U << 2)
#endif
#if defined(BPF_F_BEFORE) || (defined(HAVE_DECL_BPF_F_BEFORE) && HAVE_DECL_BPF_F_BEFORE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_BEFORE) == ((1U << 3)), "BPF_F_BEFORE != (1U << 3)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_BEFORE (1U << 3)
#endif
#if defined(BPF_F_AFTER) || (defined(HAVE_DECL_BPF_F_AFTER) && HAVE_DECL_BPF_F_AFTER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_AFTER) == ((1U << 4)), "BPF_F_AFTER != (1U << 4)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_AFTER (1U << 4)
#endif
#if defined(BPF_F_ID) || (defined(HAVE_DECL_BPF_F_ID) && HAVE_DECL_BPF_F_ID)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_ID) == ((1U << 5)), "BPF_F_ID != (1U << 5)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_ID (1U << 5)
#endif
#if defined(BPF_F_PREORDER) || (defined(HAVE_DECL_BPF_F_PREORDER) && HAVE_DECL_BPF_F_PREORDER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_PREORDER) == ((1U << 6)), "BPF_F_PREORDER != (1U << 6)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_PREORDER (1U << 6)
#endif
#if defined(BPF_F_LINK) || (defined(HAVE_DECL_BPF_F_LINK) && HAVE_DECL_BPF_F_LINK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_LINK) == ((1U << 13)), "BPF_F_LINK != (1U << 13)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_LINK (1U << 13)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat bpf_attach_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data bpf_attach_flags_xdata[] = {
 XLAT(BPF_F_ALLOW_OVERRIDE),
 #define XLAT_VAL_0 ((unsigned) (BPF_F_ALLOW_OVERRIDE))
 #define XLAT_STR_0 STRINGIFY(BPF_F_ALLOW_OVERRIDE)
 XLAT(BPF_F_ALLOW_MULTI),
 #define XLAT_VAL_1 ((unsigned) (BPF_F_ALLOW_MULTI))
 #define XLAT_STR_1 STRINGIFY(BPF_F_ALLOW_MULTI)
 XLAT(BPF_F_REPLACE),
 #define XLAT_VAL_2 ((unsigned) (BPF_F_REPLACE))
 #define XLAT_STR_2 STRINGIFY(BPF_F_REPLACE)
 XLAT(BPF_F_BEFORE),
 #define XLAT_VAL_3 ((unsigned) (BPF_F_BEFORE))
 #define XLAT_STR_3 STRINGIFY(BPF_F_BEFORE)
 XLAT(BPF_F_AFTER),
 #define XLAT_VAL_4 ((unsigned) (BPF_F_AFTER))
 #define XLAT_STR_4 STRINGIFY(BPF_F_AFTER)
 XLAT(BPF_F_ID),
 #define XLAT_VAL_5 ((unsigned) (BPF_F_ID))
 #define XLAT_STR_5 STRINGIFY(BPF_F_ID)
 XLAT(BPF_F_PREORDER),
 #define XLAT_VAL_6 ((unsigned) (BPF_F_PREORDER))
 #define XLAT_STR_6 STRINGIFY(BPF_F_PREORDER)
 XLAT(BPF_F_LINK),
 #define XLAT_VAL_7 ((unsigned) (BPF_F_LINK))
 #define XLAT_STR_7 STRINGIFY(BPF_F_LINK)
};
static
const struct xlat bpf_attach_flags[1] = { {
 .data = bpf_attach_flags_xdata,
 .size = ARRAY_SIZE(bpf_attach_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
