/* Generated by ./src/xlat/gen.sh from ./src/xlat/sock_xdp_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(XDP_MMAP_OFFSETS) || (defined(HAVE_DECL_XDP_MMAP_OFFSETS) && HAVE_DECL_XDP_MMAP_OFFSETS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_MMAP_OFFSETS) == (1), "XDP_MMAP_OFFSETS != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_MMAP_OFFSETS 1
#endif
#if defined(XDP_RX_RING) || (defined(HAVE_DECL_XDP_RX_RING) && HAVE_DECL_XDP_RX_RING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_RX_RING) == (2), "XDP_RX_RING != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_RX_RING 2
#endif
#if defined(XDP_TX_RING) || (defined(HAVE_DECL_XDP_TX_RING) && HAVE_DECL_XDP_TX_RING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_TX_RING) == (3), "XDP_TX_RING != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_TX_RING 3
#endif
#if defined(XDP_UMEM_REG) || (defined(HAVE_DECL_XDP_UMEM_REG) && HAVE_DECL_XDP_UMEM_REG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_UMEM_REG) == (4), "XDP_UMEM_REG != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_UMEM_REG 4
#endif
#if defined(XDP_UMEM_FILL_RING) || (defined(HAVE_DECL_XDP_UMEM_FILL_RING) && HAVE_DECL_XDP_UMEM_FILL_RING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_UMEM_FILL_RING) == (5), "XDP_UMEM_FILL_RING != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_UMEM_FILL_RING 5
#endif
#if defined(XDP_UMEM_COMPLETION_RING) || (defined(HAVE_DECL_XDP_UMEM_COMPLETION_RING) && HAVE_DECL_XDP_UMEM_COMPLETION_RING)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_UMEM_COMPLETION_RING) == (6), "XDP_UMEM_COMPLETION_RING != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_UMEM_COMPLETION_RING 6
#endif
#if defined(XDP_STATISTICS) || (defined(HAVE_DECL_XDP_STATISTICS) && HAVE_DECL_XDP_STATISTICS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_STATISTICS) == (7), "XDP_STATISTICS != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_STATISTICS 7
#endif
#if defined(XDP_OPTIONS) || (defined(HAVE_DECL_XDP_OPTIONS) && HAVE_DECL_XDP_OPTIONS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_OPTIONS) == (8), "XDP_OPTIONS != 8");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_OPTIONS 8
#endif
#if defined(XDP_MAX_TX_SKB_BUDGET) || (defined(HAVE_DECL_XDP_MAX_TX_SKB_BUDGET) && HAVE_DECL_XDP_MAX_TX_SKB_BUDGET)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((XDP_MAX_TX_SKB_BUDGET) == (9), "XDP_MAX_TX_SKB_BUDGET != 9");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define XDP_MAX_TX_SKB_BUDGET 9
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat sock_xdp_options in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sock_xdp_options_xdata[] = {
 [XDP_MMAP_OFFSETS] = XLAT(XDP_MMAP_OFFSETS),
 #define XLAT_VAL_0 ((unsigned) (XDP_MMAP_OFFSETS))
 #define XLAT_STR_0 STRINGIFY(XDP_MMAP_OFFSETS)
 [XDP_RX_RING] = XLAT(XDP_RX_RING),
 #define XLAT_VAL_1 ((unsigned) (XDP_RX_RING))
 #define XLAT_STR_1 STRINGIFY(XDP_RX_RING)
 [XDP_TX_RING] = XLAT(XDP_TX_RING),
 #define XLAT_VAL_2 ((unsigned) (XDP_TX_RING))
 #define XLAT_STR_2 STRINGIFY(XDP_TX_RING)
 [XDP_UMEM_REG] = XLAT(XDP_UMEM_REG),
 #define XLAT_VAL_3 ((unsigned) (XDP_UMEM_REG))
 #define XLAT_STR_3 STRINGIFY(XDP_UMEM_REG)
 [XDP_UMEM_FILL_RING] = XLAT(XDP_UMEM_FILL_RING),
 #define XLAT_VAL_4 ((unsigned) (XDP_UMEM_FILL_RING))
 #define XLAT_STR_4 STRINGIFY(XDP_UMEM_FILL_RING)
 [XDP_UMEM_COMPLETION_RING] = XLAT(XDP_UMEM_COMPLETION_RING),
 #define XLAT_VAL_5 ((unsigned) (XDP_UMEM_COMPLETION_RING))
 #define XLAT_STR_5 STRINGIFY(XDP_UMEM_COMPLETION_RING)
 [XDP_STATISTICS] = XLAT(XDP_STATISTICS),
 #define XLAT_VAL_6 ((unsigned) (XDP_STATISTICS))
 #define XLAT_STR_6 STRINGIFY(XDP_STATISTICS)
 [XDP_OPTIONS] = XLAT(XDP_OPTIONS),
 #define XLAT_VAL_7 ((unsigned) (XDP_OPTIONS))
 #define XLAT_STR_7 STRINGIFY(XDP_OPTIONS)
 [XDP_MAX_TX_SKB_BUDGET] = XLAT(XDP_MAX_TX_SKB_BUDGET),
 #define XLAT_VAL_8 ((unsigned) (XDP_MAX_TX_SKB_BUDGET))
 #define XLAT_STR_8 STRINGIFY(XDP_MAX_TX_SKB_BUDGET)
};
static
const struct xlat sock_xdp_options[1] = { {
 .data = sock_xdp_options_xdata,
 .size = ARRAY_SIZE(sock_xdp_options_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
