/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_brport_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_brport_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_brport_attrs_xdata[] = {
 [IFLA_BRPORT_UNSPEC] = XLAT(IFLA_BRPORT_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (IFLA_BRPORT_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(IFLA_BRPORT_UNSPEC)
 [IFLA_BRPORT_STATE] = XLAT(IFLA_BRPORT_STATE),
 #define XLAT_VAL_1 ((unsigned) (IFLA_BRPORT_STATE))
 #define XLAT_STR_1 STRINGIFY(IFLA_BRPORT_STATE)
 [IFLA_BRPORT_PRIORITY] = XLAT(IFLA_BRPORT_PRIORITY),
 #define XLAT_VAL_2 ((unsigned) (IFLA_BRPORT_PRIORITY))
 #define XLAT_STR_2 STRINGIFY(IFLA_BRPORT_PRIORITY)
 [IFLA_BRPORT_COST] = XLAT(IFLA_BRPORT_COST),
 #define XLAT_VAL_3 ((unsigned) (IFLA_BRPORT_COST))
 #define XLAT_STR_3 STRINGIFY(IFLA_BRPORT_COST)
 [IFLA_BRPORT_MODE] = XLAT(IFLA_BRPORT_MODE),
 #define XLAT_VAL_4 ((unsigned) (IFLA_BRPORT_MODE))
 #define XLAT_STR_4 STRINGIFY(IFLA_BRPORT_MODE)
 [IFLA_BRPORT_GUARD] = XLAT(IFLA_BRPORT_GUARD),
 #define XLAT_VAL_5 ((unsigned) (IFLA_BRPORT_GUARD))
 #define XLAT_STR_5 STRINGIFY(IFLA_BRPORT_GUARD)
 [IFLA_BRPORT_PROTECT] = XLAT(IFLA_BRPORT_PROTECT),
 #define XLAT_VAL_6 ((unsigned) (IFLA_BRPORT_PROTECT))
 #define XLAT_STR_6 STRINGIFY(IFLA_BRPORT_PROTECT)
 [IFLA_BRPORT_FAST_LEAVE] = XLAT(IFLA_BRPORT_FAST_LEAVE),
 #define XLAT_VAL_7 ((unsigned) (IFLA_BRPORT_FAST_LEAVE))
 #define XLAT_STR_7 STRINGIFY(IFLA_BRPORT_FAST_LEAVE)
 [IFLA_BRPORT_LEARNING] = XLAT(IFLA_BRPORT_LEARNING),
 #define XLAT_VAL_8 ((unsigned) (IFLA_BRPORT_LEARNING))
 #define XLAT_STR_8 STRINGIFY(IFLA_BRPORT_LEARNING)
 [IFLA_BRPORT_UNICAST_FLOOD] = XLAT(IFLA_BRPORT_UNICAST_FLOOD),
 #define XLAT_VAL_9 ((unsigned) (IFLA_BRPORT_UNICAST_FLOOD))
 #define XLAT_STR_9 STRINGIFY(IFLA_BRPORT_UNICAST_FLOOD)
 [IFLA_BRPORT_PROXYARP] = XLAT(IFLA_BRPORT_PROXYARP),
 #define XLAT_VAL_10 ((unsigned) (IFLA_BRPORT_PROXYARP))
 #define XLAT_STR_10 STRINGIFY(IFLA_BRPORT_PROXYARP)
 [IFLA_BRPORT_LEARNING_SYNC] = XLAT(IFLA_BRPORT_LEARNING_SYNC),
 #define XLAT_VAL_11 ((unsigned) (IFLA_BRPORT_LEARNING_SYNC))
 #define XLAT_STR_11 STRINGIFY(IFLA_BRPORT_LEARNING_SYNC)
 [IFLA_BRPORT_PROXYARP_WIFI] = XLAT(IFLA_BRPORT_PROXYARP_WIFI),
 #define XLAT_VAL_12 ((unsigned) (IFLA_BRPORT_PROXYARP_WIFI))
 #define XLAT_STR_12 STRINGIFY(IFLA_BRPORT_PROXYARP_WIFI)
 [IFLA_BRPORT_ROOT_ID] = XLAT(IFLA_BRPORT_ROOT_ID),
 #define XLAT_VAL_13 ((unsigned) (IFLA_BRPORT_ROOT_ID))
 #define XLAT_STR_13 STRINGIFY(IFLA_BRPORT_ROOT_ID)
 [IFLA_BRPORT_BRIDGE_ID] = XLAT(IFLA_BRPORT_BRIDGE_ID),
 #define XLAT_VAL_14 ((unsigned) (IFLA_BRPORT_BRIDGE_ID))
 #define XLAT_STR_14 STRINGIFY(IFLA_BRPORT_BRIDGE_ID)
 [IFLA_BRPORT_DESIGNATED_PORT] = XLAT(IFLA_BRPORT_DESIGNATED_PORT),
 #define XLAT_VAL_15 ((unsigned) (IFLA_BRPORT_DESIGNATED_PORT))
 #define XLAT_STR_15 STRINGIFY(IFLA_BRPORT_DESIGNATED_PORT)
 [IFLA_BRPORT_DESIGNATED_COST] = XLAT(IFLA_BRPORT_DESIGNATED_COST),
 #define XLAT_VAL_16 ((unsigned) (IFLA_BRPORT_DESIGNATED_COST))
 #define XLAT_STR_16 STRINGIFY(IFLA_BRPORT_DESIGNATED_COST)
 [IFLA_BRPORT_ID] = XLAT(IFLA_BRPORT_ID),
 #define XLAT_VAL_17 ((unsigned) (IFLA_BRPORT_ID))
 #define XLAT_STR_17 STRINGIFY(IFLA_BRPORT_ID)
 [IFLA_BRPORT_NO] = XLAT(IFLA_BRPORT_NO),
 #define XLAT_VAL_18 ((unsigned) (IFLA_BRPORT_NO))
 #define XLAT_STR_18 STRINGIFY(IFLA_BRPORT_NO)
 [IFLA_BRPORT_TOPOLOGY_CHANGE_ACK] = XLAT(IFLA_BRPORT_TOPOLOGY_CHANGE_ACK),
 #define XLAT_VAL_19 ((unsigned) (IFLA_BRPORT_TOPOLOGY_CHANGE_ACK))
 #define XLAT_STR_19 STRINGIFY(IFLA_BRPORT_TOPOLOGY_CHANGE_ACK)
 [IFLA_BRPORT_CONFIG_PENDING] = XLAT(IFLA_BRPORT_CONFIG_PENDING),
 #define XLAT_VAL_20 ((unsigned) (IFLA_BRPORT_CONFIG_PENDING))
 #define XLAT_STR_20 STRINGIFY(IFLA_BRPORT_CONFIG_PENDING)
 [IFLA_BRPORT_MESSAGE_AGE_TIMER] = XLAT(IFLA_BRPORT_MESSAGE_AGE_TIMER),
 #define XLAT_VAL_21 ((unsigned) (IFLA_BRPORT_MESSAGE_AGE_TIMER))
 #define XLAT_STR_21 STRINGIFY(IFLA_BRPORT_MESSAGE_AGE_TIMER)
 [IFLA_BRPORT_FORWARD_DELAY_TIMER] = XLAT(IFLA_BRPORT_FORWARD_DELAY_TIMER),
 #define XLAT_VAL_22 ((unsigned) (IFLA_BRPORT_FORWARD_DELAY_TIMER))
 #define XLAT_STR_22 STRINGIFY(IFLA_BRPORT_FORWARD_DELAY_TIMER)
 [IFLA_BRPORT_HOLD_TIMER] = XLAT(IFLA_BRPORT_HOLD_TIMER),
 #define XLAT_VAL_23 ((unsigned) (IFLA_BRPORT_HOLD_TIMER))
 #define XLAT_STR_23 STRINGIFY(IFLA_BRPORT_HOLD_TIMER)
 [IFLA_BRPORT_FLUSH] = XLAT(IFLA_BRPORT_FLUSH),
 #define XLAT_VAL_24 ((unsigned) (IFLA_BRPORT_FLUSH))
 #define XLAT_STR_24 STRINGIFY(IFLA_BRPORT_FLUSH)
 [IFLA_BRPORT_MULTICAST_ROUTER] = XLAT(IFLA_BRPORT_MULTICAST_ROUTER),
 #define XLAT_VAL_25 ((unsigned) (IFLA_BRPORT_MULTICAST_ROUTER))
 #define XLAT_STR_25 STRINGIFY(IFLA_BRPORT_MULTICAST_ROUTER)
 [IFLA_BRPORT_PAD] = XLAT(IFLA_BRPORT_PAD),
 #define XLAT_VAL_26 ((unsigned) (IFLA_BRPORT_PAD))
 #define XLAT_STR_26 STRINGIFY(IFLA_BRPORT_PAD)
 [IFLA_BRPORT_MCAST_FLOOD] = XLAT(IFLA_BRPORT_MCAST_FLOOD),
 #define XLAT_VAL_27 ((unsigned) (IFLA_BRPORT_MCAST_FLOOD))
 #define XLAT_STR_27 STRINGIFY(IFLA_BRPORT_MCAST_FLOOD)
 [IFLA_BRPORT_MCAST_TO_UCAST] = XLAT(IFLA_BRPORT_MCAST_TO_UCAST),
 #define XLAT_VAL_28 ((unsigned) (IFLA_BRPORT_MCAST_TO_UCAST))
 #define XLAT_STR_28 STRINGIFY(IFLA_BRPORT_MCAST_TO_UCAST)
 [IFLA_BRPORT_VLAN_TUNNEL] = XLAT(IFLA_BRPORT_VLAN_TUNNEL),
 #define XLAT_VAL_29 ((unsigned) (IFLA_BRPORT_VLAN_TUNNEL))
 #define XLAT_STR_29 STRINGIFY(IFLA_BRPORT_VLAN_TUNNEL)
 [IFLA_BRPORT_BCAST_FLOOD] = XLAT(IFLA_BRPORT_BCAST_FLOOD),
 #define XLAT_VAL_30 ((unsigned) (IFLA_BRPORT_BCAST_FLOOD))
 #define XLAT_STR_30 STRINGIFY(IFLA_BRPORT_BCAST_FLOOD)
 [IFLA_BRPORT_GROUP_FWD_MASK] = XLAT(IFLA_BRPORT_GROUP_FWD_MASK),
 #define XLAT_VAL_31 ((unsigned) (IFLA_BRPORT_GROUP_FWD_MASK))
 #define XLAT_STR_31 STRINGIFY(IFLA_BRPORT_GROUP_FWD_MASK)
 [IFLA_BRPORT_NEIGH_SUPPRESS] = XLAT(IFLA_BRPORT_NEIGH_SUPPRESS),
 #define XLAT_VAL_32 ((unsigned) (IFLA_BRPORT_NEIGH_SUPPRESS))
 #define XLAT_STR_32 STRINGIFY(IFLA_BRPORT_NEIGH_SUPPRESS)
 [IFLA_BRPORT_ISOLATED] = XLAT(IFLA_BRPORT_ISOLATED),
 #define XLAT_VAL_33 ((unsigned) (IFLA_BRPORT_ISOLATED))
 #define XLAT_STR_33 STRINGIFY(IFLA_BRPORT_ISOLATED)
 [IFLA_BRPORT_BACKUP_PORT] = XLAT(IFLA_BRPORT_BACKUP_PORT),
 #define XLAT_VAL_34 ((unsigned) (IFLA_BRPORT_BACKUP_PORT))
 #define XLAT_STR_34 STRINGIFY(IFLA_BRPORT_BACKUP_PORT)
 [IFLA_BRPORT_MRP_RING_OPEN] = XLAT(IFLA_BRPORT_MRP_RING_OPEN),
 #define XLAT_VAL_35 ((unsigned) (IFLA_BRPORT_MRP_RING_OPEN))
 #define XLAT_STR_35 STRINGIFY(IFLA_BRPORT_MRP_RING_OPEN)
 [IFLA_BRPORT_MRP_IN_OPEN] = XLAT(IFLA_BRPORT_MRP_IN_OPEN),
 #define XLAT_VAL_36 ((unsigned) (IFLA_BRPORT_MRP_IN_OPEN))
 #define XLAT_STR_36 STRINGIFY(IFLA_BRPORT_MRP_IN_OPEN)
 [IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT] = XLAT(IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT),
 #define XLAT_VAL_37 ((unsigned) (IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT))
 #define XLAT_STR_37 STRINGIFY(IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT)
 [IFLA_BRPORT_MCAST_EHT_HOSTS_CNT] = XLAT(IFLA_BRPORT_MCAST_EHT_HOSTS_CNT),
 #define XLAT_VAL_38 ((unsigned) (IFLA_BRPORT_MCAST_EHT_HOSTS_CNT))
 #define XLAT_STR_38 STRINGIFY(IFLA_BRPORT_MCAST_EHT_HOSTS_CNT)
 [IFLA_BRPORT_LOCKED] = XLAT(IFLA_BRPORT_LOCKED),
 #define XLAT_VAL_39 ((unsigned) (IFLA_BRPORT_LOCKED))
 #define XLAT_STR_39 STRINGIFY(IFLA_BRPORT_LOCKED)
 [IFLA_BRPORT_MAB] = XLAT(IFLA_BRPORT_MAB),
 #define XLAT_VAL_40 ((unsigned) (IFLA_BRPORT_MAB))
 #define XLAT_STR_40 STRINGIFY(IFLA_BRPORT_MAB)
 [IFLA_BRPORT_MCAST_N_GROUPS] = XLAT(IFLA_BRPORT_MCAST_N_GROUPS),
 #define XLAT_VAL_41 ((unsigned) (IFLA_BRPORT_MCAST_N_GROUPS))
 #define XLAT_STR_41 STRINGIFY(IFLA_BRPORT_MCAST_N_GROUPS)
 [IFLA_BRPORT_MCAST_MAX_GROUPS] = XLAT(IFLA_BRPORT_MCAST_MAX_GROUPS),
 #define XLAT_VAL_42 ((unsigned) (IFLA_BRPORT_MCAST_MAX_GROUPS))
 #define XLAT_STR_42 STRINGIFY(IFLA_BRPORT_MCAST_MAX_GROUPS)
 [IFLA_BRPORT_NEIGH_VLAN_SUPPRESS] = XLAT(IFLA_BRPORT_NEIGH_VLAN_SUPPRESS),
 #define XLAT_VAL_43 ((unsigned) (IFLA_BRPORT_NEIGH_VLAN_SUPPRESS))
 #define XLAT_STR_43 STRINGIFY(IFLA_BRPORT_NEIGH_VLAN_SUPPRESS)
 [IFLA_BRPORT_BACKUP_NHID] = XLAT(IFLA_BRPORT_BACKUP_NHID),
 #define XLAT_VAL_44 ((unsigned) (IFLA_BRPORT_BACKUP_NHID))
 #define XLAT_STR_44 STRINGIFY(IFLA_BRPORT_BACKUP_NHID)
};
static
const struct xlat rtnl_ifla_brport_attrs[1] = { {
 .data = rtnl_ifla_brport_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_brport_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
#  ifdef XLAT_VAL_42
  | XLAT_VAL_42
#  endif
#  ifdef XLAT_VAL_43
  | XLAT_VAL_43
#  endif
#  ifdef XLAT_VAL_44
  | XLAT_VAL_44
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
#  ifdef XLAT_STR_42
  + sizeof(XLAT_STR_42)
#  endif
#  ifdef XLAT_STR_43
  + sizeof(XLAT_STR_43)
#  endif
#  ifdef XLAT_STR_44
  + sizeof(XLAT_STR_44)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
#  undef XLAT_STR_42
#  undef XLAT_VAL_42
#  undef XLAT_STR_43
#  undef XLAT_VAL_43
#  undef XLAT_STR_44
#  undef XLAT_VAL_44
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
