/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_br_boolopt_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_br_boolopt_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_br_boolopt_flags_xdata[] = {
 XLAT_PAIR(1ULL<<BR_BOOLOPT_NO_LL_LEARN, "1<<BR_BOOLOPT_NO_LL_LEARN"),
 #define XLAT_VAL_0 ((unsigned) (1ULL<<BR_BOOLOPT_NO_LL_LEARN))
 #define XLAT_STR_0 "1<<BR_BOOLOPT_NO_LL_LEARN"
 XLAT_PAIR(1ULL<<BR_BOOLOPT_MCAST_VLAN_SNOOPING, "1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING"),
 #define XLAT_VAL_1 ((unsigned) (1ULL<<BR_BOOLOPT_MCAST_VLAN_SNOOPING))
 #define XLAT_STR_1 "1<<BR_BOOLOPT_MCAST_VLAN_SNOOPING"
 XLAT_PAIR(1ULL<<BR_BOOLOPT_MST_ENABLE, "1<<BR_BOOLOPT_MST_ENABLE"),
 #define XLAT_VAL_2 ((unsigned) (1ULL<<BR_BOOLOPT_MST_ENABLE))
 #define XLAT_STR_2 "1<<BR_BOOLOPT_MST_ENABLE"
 XLAT_PAIR(1ULL<<BR_BOOLOPT_MDB_OFFLOAD_FAIL_NOTIFICATION, "1<<BR_BOOLOPT_MDB_OFFLOAD_FAIL_NOTIFICATION"),
 #define XLAT_VAL_3 ((unsigned) (1ULL<<BR_BOOLOPT_MDB_OFFLOAD_FAIL_NOTIFICATION))
 #define XLAT_STR_3 "1<<BR_BOOLOPT_MDB_OFFLOAD_FAIL_NOTIFICATION"
 XLAT_PAIR(1ULL<<BR_BOOLOPT_FDB_LOCAL_VLAN_0, "1<<BR_BOOLOPT_FDB_LOCAL_VLAN_0"),
 #define XLAT_VAL_4 ((unsigned) (1ULL<<BR_BOOLOPT_FDB_LOCAL_VLAN_0))
 #define XLAT_STR_4 "1<<BR_BOOLOPT_FDB_LOCAL_VLAN_0"
};
static
const struct xlat rtnl_ifla_br_boolopt_flags[1] = { {
 .data = rtnl_ifla_br_boolopt_flags_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_br_boolopt_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
