/* Generated by ./src/xlat/gen.sh from ./src/xlat/key_perms.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(KEY_POS_VIEW) || (defined(HAVE_DECL_KEY_POS_VIEW) && HAVE_DECL_KEY_POS_VIEW)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_VIEW) == (0x01000000), "KEY_POS_VIEW != 0x01000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_VIEW 0x01000000
#endif
#if defined(KEY_POS_READ) || (defined(HAVE_DECL_KEY_POS_READ) && HAVE_DECL_KEY_POS_READ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_READ) == (0x02000000), "KEY_POS_READ != 0x02000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_READ 0x02000000
#endif
#if defined(KEY_POS_WRITE) || (defined(HAVE_DECL_KEY_POS_WRITE) && HAVE_DECL_KEY_POS_WRITE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_WRITE) == (0x04000000), "KEY_POS_WRITE != 0x04000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_WRITE 0x04000000
#endif
#if defined(KEY_POS_SEARCH) || (defined(HAVE_DECL_KEY_POS_SEARCH) && HAVE_DECL_KEY_POS_SEARCH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_SEARCH) == (0x08000000), "KEY_POS_SEARCH != 0x08000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_SEARCH 0x08000000
#endif
#if defined(KEY_POS_LINK) || (defined(HAVE_DECL_KEY_POS_LINK) && HAVE_DECL_KEY_POS_LINK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_LINK) == (0x10000000), "KEY_POS_LINK != 0x10000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_LINK 0x10000000
#endif
#if defined(KEY_POS_SETATTR) || (defined(HAVE_DECL_KEY_POS_SETATTR) && HAVE_DECL_KEY_POS_SETATTR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_SETATTR) == (0x20000000), "KEY_POS_SETATTR != 0x20000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_SETATTR 0x20000000
#endif
#if defined(KEY_POS_ALL) || (defined(HAVE_DECL_KEY_POS_ALL) && HAVE_DECL_KEY_POS_ALL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_POS_ALL) == (0x3f000000), "KEY_POS_ALL != 0x3f000000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_POS_ALL 0x3f000000
#endif
#if defined(KEY_USR_VIEW) || (defined(HAVE_DECL_KEY_USR_VIEW) && HAVE_DECL_KEY_USR_VIEW)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_VIEW) == (0x00010000), "KEY_USR_VIEW != 0x00010000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_VIEW 0x00010000
#endif
#if defined(KEY_USR_READ) || (defined(HAVE_DECL_KEY_USR_READ) && HAVE_DECL_KEY_USR_READ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_READ) == (0x00020000), "KEY_USR_READ != 0x00020000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_READ 0x00020000
#endif
#if defined(KEY_USR_WRITE) || (defined(HAVE_DECL_KEY_USR_WRITE) && HAVE_DECL_KEY_USR_WRITE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_WRITE) == (0x00040000), "KEY_USR_WRITE != 0x00040000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_WRITE 0x00040000
#endif
#if defined(KEY_USR_SEARCH) || (defined(HAVE_DECL_KEY_USR_SEARCH) && HAVE_DECL_KEY_USR_SEARCH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_SEARCH) == (0x00080000), "KEY_USR_SEARCH != 0x00080000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_SEARCH 0x00080000
#endif
#if defined(KEY_USR_LINK) || (defined(HAVE_DECL_KEY_USR_LINK) && HAVE_DECL_KEY_USR_LINK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_LINK) == (0x00100000), "KEY_USR_LINK != 0x00100000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_LINK 0x00100000
#endif
#if defined(KEY_USR_SETATTR) || (defined(HAVE_DECL_KEY_USR_SETATTR) && HAVE_DECL_KEY_USR_SETATTR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_SETATTR) == (0x00200000), "KEY_USR_SETATTR != 0x00200000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_SETATTR 0x00200000
#endif
#if defined(KEY_USR_ALL) || (defined(HAVE_DECL_KEY_USR_ALL) && HAVE_DECL_KEY_USR_ALL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_USR_ALL) == (0x003f0000), "KEY_USR_ALL != 0x003f0000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_USR_ALL 0x003f0000
#endif
#if defined(KEY_GRP_VIEW) || (defined(HAVE_DECL_KEY_GRP_VIEW) && HAVE_DECL_KEY_GRP_VIEW)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_VIEW) == (0x00000100), "KEY_GRP_VIEW != 0x00000100");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_VIEW 0x00000100
#endif
#if defined(KEY_GRP_READ) || (defined(HAVE_DECL_KEY_GRP_READ) && HAVE_DECL_KEY_GRP_READ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_READ) == (0x00000200), "KEY_GRP_READ != 0x00000200");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_READ 0x00000200
#endif
#if defined(KEY_GRP_WRITE) || (defined(HAVE_DECL_KEY_GRP_WRITE) && HAVE_DECL_KEY_GRP_WRITE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_WRITE) == (0x00000400), "KEY_GRP_WRITE != 0x00000400");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_WRITE 0x00000400
#endif
#if defined(KEY_GRP_SEARCH) || (defined(HAVE_DECL_KEY_GRP_SEARCH) && HAVE_DECL_KEY_GRP_SEARCH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_SEARCH) == (0x00000800), "KEY_GRP_SEARCH != 0x00000800");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_SEARCH 0x00000800
#endif
#if defined(KEY_GRP_LINK) || (defined(HAVE_DECL_KEY_GRP_LINK) && HAVE_DECL_KEY_GRP_LINK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_LINK) == (0x00001000), "KEY_GRP_LINK != 0x00001000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_LINK 0x00001000
#endif
#if defined(KEY_GRP_SETATTR) || (defined(HAVE_DECL_KEY_GRP_SETATTR) && HAVE_DECL_KEY_GRP_SETATTR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_SETATTR) == (0x00002000), "KEY_GRP_SETATTR != 0x00002000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_SETATTR 0x00002000
#endif
#if defined(KEY_GRP_ALL) || (defined(HAVE_DECL_KEY_GRP_ALL) && HAVE_DECL_KEY_GRP_ALL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_GRP_ALL) == (0x00003f00), "KEY_GRP_ALL != 0x00003f00");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_GRP_ALL 0x00003f00
#endif
#if defined(KEY_OTH_VIEW) || (defined(HAVE_DECL_KEY_OTH_VIEW) && HAVE_DECL_KEY_OTH_VIEW)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_VIEW) == (0x00000001), "KEY_OTH_VIEW != 0x00000001");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_VIEW 0x00000001
#endif
#if defined(KEY_OTH_READ) || (defined(HAVE_DECL_KEY_OTH_READ) && HAVE_DECL_KEY_OTH_READ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_READ) == (0x00000002), "KEY_OTH_READ != 0x00000002");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_READ 0x00000002
#endif
#if defined(KEY_OTH_WRITE) || (defined(HAVE_DECL_KEY_OTH_WRITE) && HAVE_DECL_KEY_OTH_WRITE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_WRITE) == (0x00000004), "KEY_OTH_WRITE != 0x00000004");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_WRITE 0x00000004
#endif
#if defined(KEY_OTH_SEARCH) || (defined(HAVE_DECL_KEY_OTH_SEARCH) && HAVE_DECL_KEY_OTH_SEARCH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_SEARCH) == (0x00000008), "KEY_OTH_SEARCH != 0x00000008");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_SEARCH 0x00000008
#endif
#if defined(KEY_OTH_LINK) || (defined(HAVE_DECL_KEY_OTH_LINK) && HAVE_DECL_KEY_OTH_LINK)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_LINK) == (0x00000010), "KEY_OTH_LINK != 0x00000010");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_LINK 0x00000010
#endif
#if defined(KEY_OTH_SETATTR) || (defined(HAVE_DECL_KEY_OTH_SETATTR) && HAVE_DECL_KEY_OTH_SETATTR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_SETATTR) == (0x00000020), "KEY_OTH_SETATTR != 0x00000020");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_SETATTR 0x00000020
#endif
#if defined(KEY_OTH_ALL) || (defined(HAVE_DECL_KEY_OTH_ALL) && HAVE_DECL_KEY_OTH_ALL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KEY_OTH_ALL) == (0x0000003f), "KEY_OTH_ALL != 0x0000003f");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KEY_OTH_ALL 0x0000003f
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat key_perms in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data key_perms_xdata[] = {
 XLAT(KEY_POS_VIEW),
 #define XLAT_VAL_0 ((unsigned) (KEY_POS_VIEW))
 #define XLAT_STR_0 STRINGIFY(KEY_POS_VIEW)
 XLAT(KEY_POS_READ),
 #define XLAT_VAL_1 ((unsigned) (KEY_POS_READ))
 #define XLAT_STR_1 STRINGIFY(KEY_POS_READ)
 XLAT(KEY_POS_WRITE),
 #define XLAT_VAL_2 ((unsigned) (KEY_POS_WRITE))
 #define XLAT_STR_2 STRINGIFY(KEY_POS_WRITE)
 XLAT(KEY_POS_SEARCH),
 #define XLAT_VAL_3 ((unsigned) (KEY_POS_SEARCH))
 #define XLAT_STR_3 STRINGIFY(KEY_POS_SEARCH)
 XLAT(KEY_POS_LINK),
 #define XLAT_VAL_4 ((unsigned) (KEY_POS_LINK))
 #define XLAT_STR_4 STRINGIFY(KEY_POS_LINK)
 XLAT(KEY_POS_SETATTR),
 #define XLAT_VAL_5 ((unsigned) (KEY_POS_SETATTR))
 #define XLAT_STR_5 STRINGIFY(KEY_POS_SETATTR)
 XLAT(KEY_POS_ALL),
 #define XLAT_VAL_6 ((unsigned) (KEY_POS_ALL))
 #define XLAT_STR_6 STRINGIFY(KEY_POS_ALL)
 XLAT(KEY_USR_VIEW),
 #define XLAT_VAL_7 ((unsigned) (KEY_USR_VIEW))
 #define XLAT_STR_7 STRINGIFY(KEY_USR_VIEW)
 XLAT(KEY_USR_READ),
 #define XLAT_VAL_8 ((unsigned) (KEY_USR_READ))
 #define XLAT_STR_8 STRINGIFY(KEY_USR_READ)
 XLAT(KEY_USR_WRITE),
 #define XLAT_VAL_9 ((unsigned) (KEY_USR_WRITE))
 #define XLAT_STR_9 STRINGIFY(KEY_USR_WRITE)
 XLAT(KEY_USR_SEARCH),
 #define XLAT_VAL_10 ((unsigned) (KEY_USR_SEARCH))
 #define XLAT_STR_10 STRINGIFY(KEY_USR_SEARCH)
 XLAT(KEY_USR_LINK),
 #define XLAT_VAL_11 ((unsigned) (KEY_USR_LINK))
 #define XLAT_STR_11 STRINGIFY(KEY_USR_LINK)
 XLAT(KEY_USR_SETATTR),
 #define XLAT_VAL_12 ((unsigned) (KEY_USR_SETATTR))
 #define XLAT_STR_12 STRINGIFY(KEY_USR_SETATTR)
 XLAT(KEY_USR_ALL),
 #define XLAT_VAL_13 ((unsigned) (KEY_USR_ALL))
 #define XLAT_STR_13 STRINGIFY(KEY_USR_ALL)
 XLAT(KEY_GRP_VIEW),
 #define XLAT_VAL_14 ((unsigned) (KEY_GRP_VIEW))
 #define XLAT_STR_14 STRINGIFY(KEY_GRP_VIEW)
 XLAT(KEY_GRP_READ),
 #define XLAT_VAL_15 ((unsigned) (KEY_GRP_READ))
 #define XLAT_STR_15 STRINGIFY(KEY_GRP_READ)
 XLAT(KEY_GRP_WRITE),
 #define XLAT_VAL_16 ((unsigned) (KEY_GRP_WRITE))
 #define XLAT_STR_16 STRINGIFY(KEY_GRP_WRITE)
 XLAT(KEY_GRP_SEARCH),
 #define XLAT_VAL_17 ((unsigned) (KEY_GRP_SEARCH))
 #define XLAT_STR_17 STRINGIFY(KEY_GRP_SEARCH)
 XLAT(KEY_GRP_LINK),
 #define XLAT_VAL_18 ((unsigned) (KEY_GRP_LINK))
 #define XLAT_STR_18 STRINGIFY(KEY_GRP_LINK)
 XLAT(KEY_GRP_SETATTR),
 #define XLAT_VAL_19 ((unsigned) (KEY_GRP_SETATTR))
 #define XLAT_STR_19 STRINGIFY(KEY_GRP_SETATTR)
 XLAT(KEY_GRP_ALL),
 #define XLAT_VAL_20 ((unsigned) (KEY_GRP_ALL))
 #define XLAT_STR_20 STRINGIFY(KEY_GRP_ALL)
 XLAT(KEY_OTH_VIEW),
 #define XLAT_VAL_21 ((unsigned) (KEY_OTH_VIEW))
 #define XLAT_STR_21 STRINGIFY(KEY_OTH_VIEW)
 XLAT(KEY_OTH_READ),
 #define XLAT_VAL_22 ((unsigned) (KEY_OTH_READ))
 #define XLAT_STR_22 STRINGIFY(KEY_OTH_READ)
 XLAT(KEY_OTH_WRITE),
 #define XLAT_VAL_23 ((unsigned) (KEY_OTH_WRITE))
 #define XLAT_STR_23 STRINGIFY(KEY_OTH_WRITE)
 XLAT(KEY_OTH_SEARCH),
 #define XLAT_VAL_24 ((unsigned) (KEY_OTH_SEARCH))
 #define XLAT_STR_24 STRINGIFY(KEY_OTH_SEARCH)
 XLAT(KEY_OTH_LINK),
 #define XLAT_VAL_25 ((unsigned) (KEY_OTH_LINK))
 #define XLAT_STR_25 STRINGIFY(KEY_OTH_LINK)
 XLAT(KEY_OTH_SETATTR),
 #define XLAT_VAL_26 ((unsigned) (KEY_OTH_SETATTR))
 #define XLAT_STR_26 STRINGIFY(KEY_OTH_SETATTR)
 XLAT(KEY_OTH_ALL),
 #define XLAT_VAL_27 ((unsigned) (KEY_OTH_ALL))
 #define XLAT_STR_27 STRINGIFY(KEY_OTH_ALL)
};
static
const struct xlat key_perms[1] = { {
 .data = key_perms_xdata,
 .size = ARRAY_SIZE(key_perms_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
