/* Generated by ./src/xlat/gen.sh from ./src/xlat/pr_riscv_icache_flush_ctxes.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(PR_RISCV_CTX_SW_FENCEI_ON) || (defined(HAVE_DECL_PR_RISCV_CTX_SW_FENCEI_ON) && HAVE_DECL_PR_RISCV_CTX_SW_FENCEI_ON)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PR_RISCV_CTX_SW_FENCEI_ON) == (0), "PR_RISCV_CTX_SW_FENCEI_ON != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PR_RISCV_CTX_SW_FENCEI_ON 0
#endif
#if defined(PR_RISCV_CTX_SW_FENCEI_OFF) || (defined(HAVE_DECL_PR_RISCV_CTX_SW_FENCEI_OFF) && HAVE_DECL_PR_RISCV_CTX_SW_FENCEI_OFF)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PR_RISCV_CTX_SW_FENCEI_OFF) == (1), "PR_RISCV_CTX_SW_FENCEI_OFF != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PR_RISCV_CTX_SW_FENCEI_OFF 1
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat pr_riscv_icache_flush_ctxes in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data pr_riscv_icache_flush_ctxes_xdata[] = {
 [PR_RISCV_CTX_SW_FENCEI_ON] = XLAT(PR_RISCV_CTX_SW_FENCEI_ON),
 #define XLAT_VAL_0 ((unsigned) (PR_RISCV_CTX_SW_FENCEI_ON))
 #define XLAT_STR_0 STRINGIFY(PR_RISCV_CTX_SW_FENCEI_ON)
 [PR_RISCV_CTX_SW_FENCEI_OFF] = XLAT(PR_RISCV_CTX_SW_FENCEI_OFF),
 #define XLAT_VAL_1 ((unsigned) (PR_RISCV_CTX_SW_FENCEI_OFF))
 #define XLAT_STR_1 STRINGIFY(PR_RISCV_CTX_SW_FENCEI_OFF)
};
static
const struct xlat pr_riscv_icache_flush_ctxes[1] = { {
 .data = pr_riscv_icache_flush_ctxes_xdata,
 .size = ARRAY_SIZE(pr_riscv_icache_flush_ctxes_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
