/* Generated by ./src/xlat/gen.sh from ./src/xlat/mctp_addrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCTP_ADDR_NULL) == (0x00), "MCTP_ADDR_NULL != 0x00");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MCTP_ADDR_ANY) == (0xff), "MCTP_ADDR_ANY != 0xff");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat mctp_addrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data mctp_addrs_xdata[] = {
 XLAT(MCTP_ADDR_NULL),
 #define XLAT_VAL_0 ((unsigned) (MCTP_ADDR_NULL))
 #define XLAT_STR_0 STRINGIFY(MCTP_ADDR_NULL)
 XLAT(MCTP_ADDR_ANY),
 #define XLAT_VAL_1 ((unsigned) (MCTP_ADDR_ANY))
 #define XLAT_STR_1 STRINGIFY(MCTP_ADDR_ANY)
};
static
const struct xlat mctp_addrs[1] = { {
 .data = mctp_addrs_xdata,
 .size = ARRAY_SIZE(mctp_addrs_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
