/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_rule_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_rule_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_rule_attrs_xdata[] = {
 [FRA_UNSPEC] = XLAT(FRA_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (FRA_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(FRA_UNSPEC)
 [FRA_DST] = XLAT(FRA_DST),
 #define XLAT_VAL_1 ((unsigned) (FRA_DST))
 #define XLAT_STR_1 STRINGIFY(FRA_DST)
 [FRA_SRC] = XLAT(FRA_SRC),
 #define XLAT_VAL_2 ((unsigned) (FRA_SRC))
 #define XLAT_STR_2 STRINGIFY(FRA_SRC)
 [FRA_IIFNAME] = XLAT(FRA_IIFNAME),
 #define XLAT_VAL_3 ((unsigned) (FRA_IIFNAME))
 #define XLAT_STR_3 STRINGIFY(FRA_IIFNAME)
 [FRA_GOTO] = XLAT(FRA_GOTO),
 #define XLAT_VAL_4 ((unsigned) (FRA_GOTO))
 #define XLAT_STR_4 STRINGIFY(FRA_GOTO)
 [FRA_UNUSED2] = XLAT(FRA_UNUSED2),
 #define XLAT_VAL_5 ((unsigned) (FRA_UNUSED2))
 #define XLAT_STR_5 STRINGIFY(FRA_UNUSED2)
 [FRA_PRIORITY] = XLAT(FRA_PRIORITY),
 #define XLAT_VAL_6 ((unsigned) (FRA_PRIORITY))
 #define XLAT_STR_6 STRINGIFY(FRA_PRIORITY)
 [FRA_UNUSED3] = XLAT(FRA_UNUSED3),
 #define XLAT_VAL_7 ((unsigned) (FRA_UNUSED3))
 #define XLAT_STR_7 STRINGIFY(FRA_UNUSED3)
 [FRA_UNUSED4] = XLAT(FRA_UNUSED4),
 #define XLAT_VAL_8 ((unsigned) (FRA_UNUSED4))
 #define XLAT_STR_8 STRINGIFY(FRA_UNUSED4)
 [FRA_UNUSED5] = XLAT(FRA_UNUSED5),
 #define XLAT_VAL_9 ((unsigned) (FRA_UNUSED5))
 #define XLAT_STR_9 STRINGIFY(FRA_UNUSED5)
 [FRA_FWMARK] = XLAT(FRA_FWMARK),
 #define XLAT_VAL_10 ((unsigned) (FRA_FWMARK))
 #define XLAT_STR_10 STRINGIFY(FRA_FWMARK)
 [FRA_FLOW] = XLAT(FRA_FLOW),
 #define XLAT_VAL_11 ((unsigned) (FRA_FLOW))
 #define XLAT_STR_11 STRINGIFY(FRA_FLOW)
 [FRA_TUN_ID] = XLAT(FRA_TUN_ID),
 #define XLAT_VAL_12 ((unsigned) (FRA_TUN_ID))
 #define XLAT_STR_12 STRINGIFY(FRA_TUN_ID)
 [FRA_SUPPRESS_IFGROUP] = XLAT(FRA_SUPPRESS_IFGROUP),
 #define XLAT_VAL_13 ((unsigned) (FRA_SUPPRESS_IFGROUP))
 #define XLAT_STR_13 STRINGIFY(FRA_SUPPRESS_IFGROUP)
 [FRA_SUPPRESS_PREFIXLEN] = XLAT(FRA_SUPPRESS_PREFIXLEN),
 #define XLAT_VAL_14 ((unsigned) (FRA_SUPPRESS_PREFIXLEN))
 #define XLAT_STR_14 STRINGIFY(FRA_SUPPRESS_PREFIXLEN)
 [FRA_TABLE] = XLAT(FRA_TABLE),
 #define XLAT_VAL_15 ((unsigned) (FRA_TABLE))
 #define XLAT_STR_15 STRINGIFY(FRA_TABLE)
 [FRA_FWMASK] = XLAT(FRA_FWMASK),
 #define XLAT_VAL_16 ((unsigned) (FRA_FWMASK))
 #define XLAT_STR_16 STRINGIFY(FRA_FWMASK)
 [FRA_OIFNAME] = XLAT(FRA_OIFNAME),
 #define XLAT_VAL_17 ((unsigned) (FRA_OIFNAME))
 #define XLAT_STR_17 STRINGIFY(FRA_OIFNAME)
 [FRA_PAD] = XLAT(FRA_PAD),
 #define XLAT_VAL_18 ((unsigned) (FRA_PAD))
 #define XLAT_STR_18 STRINGIFY(FRA_PAD)
 [FRA_L3MDEV] = XLAT(FRA_L3MDEV),
 #define XLAT_VAL_19 ((unsigned) (FRA_L3MDEV))
 #define XLAT_STR_19 STRINGIFY(FRA_L3MDEV)
 [FRA_UID_RANGE] = XLAT(FRA_UID_RANGE),
 #define XLAT_VAL_20 ((unsigned) (FRA_UID_RANGE))
 #define XLAT_STR_20 STRINGIFY(FRA_UID_RANGE)
 [FRA_PROTOCOL] = XLAT(FRA_PROTOCOL),
 #define XLAT_VAL_21 ((unsigned) (FRA_PROTOCOL))
 #define XLAT_STR_21 STRINGIFY(FRA_PROTOCOL)
 [FRA_IP_PROTO] = XLAT(FRA_IP_PROTO),
 #define XLAT_VAL_22 ((unsigned) (FRA_IP_PROTO))
 #define XLAT_STR_22 STRINGIFY(FRA_IP_PROTO)
 [FRA_SPORT_RANGE] = XLAT(FRA_SPORT_RANGE),
 #define XLAT_VAL_23 ((unsigned) (FRA_SPORT_RANGE))
 #define XLAT_STR_23 STRINGIFY(FRA_SPORT_RANGE)
 [FRA_DPORT_RANGE] = XLAT(FRA_DPORT_RANGE),
 #define XLAT_VAL_24 ((unsigned) (FRA_DPORT_RANGE))
 #define XLAT_STR_24 STRINGIFY(FRA_DPORT_RANGE)
 [FRA_DSCP] = XLAT(FRA_DSCP),
 #define XLAT_VAL_25 ((unsigned) (FRA_DSCP))
 #define XLAT_STR_25 STRINGIFY(FRA_DSCP)
 [FRA_FLOWLABEL] = XLAT(FRA_FLOWLABEL),
 #define XLAT_VAL_26 ((unsigned) (FRA_FLOWLABEL))
 #define XLAT_STR_26 STRINGIFY(FRA_FLOWLABEL)
 [FRA_FLOWLABEL_MASK] = XLAT(FRA_FLOWLABEL_MASK),
 #define XLAT_VAL_27 ((unsigned) (FRA_FLOWLABEL_MASK))
 #define XLAT_STR_27 STRINGIFY(FRA_FLOWLABEL_MASK)
 [FRA_SPORT_MASK] = XLAT(FRA_SPORT_MASK),
 #define XLAT_VAL_28 ((unsigned) (FRA_SPORT_MASK))
 #define XLAT_STR_28 STRINGIFY(FRA_SPORT_MASK)
 [FRA_DPORT_MASK] = XLAT(FRA_DPORT_MASK),
 #define XLAT_VAL_29 ((unsigned) (FRA_DPORT_MASK))
 #define XLAT_STR_29 STRINGIFY(FRA_DPORT_MASK)
 [FRA_DSCP_MASK] = XLAT(FRA_DSCP_MASK),
 #define XLAT_VAL_30 ((unsigned) (FRA_DSCP_MASK))
 #define XLAT_STR_30 STRINGIFY(FRA_DSCP_MASK)
};
static
const struct xlat rtnl_rule_attrs[1] = { {
 .data = rtnl_rule_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_rule_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
