/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_nexthop_grp_types.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NEXTHOP_GRP_TYPE_MPATH) == (0), "NEXTHOP_GRP_TYPE_MPATH != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NEXTHOP_GRP_TYPE_RES) == (1), "NEXTHOP_GRP_TYPE_RES != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_nexthop_grp_types in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_nexthop_grp_types_xdata[] = {
 [NEXTHOP_GRP_TYPE_MPATH] = XLAT(NEXTHOP_GRP_TYPE_MPATH),
 #define XLAT_VAL_0 ((unsigned) (NEXTHOP_GRP_TYPE_MPATH))
 #define XLAT_STR_0 STRINGIFY(NEXTHOP_GRP_TYPE_MPATH)
 [NEXTHOP_GRP_TYPE_RES] = XLAT(NEXTHOP_GRP_TYPE_RES),
 #define XLAT_VAL_1 ((unsigned) (NEXTHOP_GRP_TYPE_RES))
 #define XLAT_STR_1 STRINGIFY(NEXTHOP_GRP_TYPE_RES)
};
static
const struct xlat rtnl_nexthop_grp_types[1] = { {
 .data = rtnl_nexthop_grp_types_xdata,
 .size = ARRAY_SIZE(rtnl_nexthop_grp_types_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
