/* Generated by ./src/xlat/gen.sh from ./src/xlat/futex2_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_NUMA) == (0x04), "FUTEX2_NUMA != 0x04");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_MPOL) == (0x08), "FUTEX2_MPOL != 0x08");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_PRIVATE) == (0x80), "FUTEX2_PRIVATE != 0x80");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat futex2_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data futex2_flags_xdata[] = {
 XLAT(FUTEX2_NUMA),
 #define XLAT_VAL_0 ((unsigned) (FUTEX2_NUMA))
 #define XLAT_STR_0 STRINGIFY(FUTEX2_NUMA)
 XLAT(FUTEX2_MPOL),
 #define XLAT_VAL_1 ((unsigned) (FUTEX2_MPOL))
 #define XLAT_STR_1 STRINGIFY(FUTEX2_MPOL)
 XLAT(FUTEX2_PRIVATE),
 #define XLAT_VAL_2 ((unsigned) (FUTEX2_PRIVATE))
 #define XLAT_STR_2 STRINGIFY(FUTEX2_PRIVATE)
};
static
const struct xlat futex2_flags[1] = { {
 .data = futex2_flags_xdata,
 .size = ARRAY_SIZE(futex2_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
