/* Generated by ./src/xlat/gen.sh from ./src/xlat/socketcalls.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(SYS_SOCKET) || (defined(HAVE_DECL_SYS_SOCKET) && HAVE_DECL_SYS_SOCKET)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SOCKET) == (1), "SYS_SOCKET != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SOCKET 1
#endif
#if defined(SYS_BIND) || (defined(HAVE_DECL_SYS_BIND) && HAVE_DECL_SYS_BIND)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_BIND) == (2), "SYS_BIND != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_BIND 2
#endif
#if defined(SYS_CONNECT) || (defined(HAVE_DECL_SYS_CONNECT) && HAVE_DECL_SYS_CONNECT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_CONNECT) == (3), "SYS_CONNECT != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_CONNECT 3
#endif
#if defined(SYS_LISTEN) || (defined(HAVE_DECL_SYS_LISTEN) && HAVE_DECL_SYS_LISTEN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_LISTEN) == (4), "SYS_LISTEN != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_LISTEN 4
#endif
#if defined(SYS_ACCEPT) || (defined(HAVE_DECL_SYS_ACCEPT) && HAVE_DECL_SYS_ACCEPT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_ACCEPT) == (5), "SYS_ACCEPT != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_ACCEPT 5
#endif
#if defined(SYS_GETSOCKNAME) || (defined(HAVE_DECL_SYS_GETSOCKNAME) && HAVE_DECL_SYS_GETSOCKNAME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_GETSOCKNAME) == (6), "SYS_GETSOCKNAME != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_GETSOCKNAME 6
#endif
#if defined(SYS_GETPEERNAME) || (defined(HAVE_DECL_SYS_GETPEERNAME) && HAVE_DECL_SYS_GETPEERNAME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_GETPEERNAME) == (7), "SYS_GETPEERNAME != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_GETPEERNAME 7
#endif
#if defined(SYS_SOCKETPAIR) || (defined(HAVE_DECL_SYS_SOCKETPAIR) && HAVE_DECL_SYS_SOCKETPAIR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SOCKETPAIR) == (8), "SYS_SOCKETPAIR != 8");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SOCKETPAIR 8
#endif
#if defined(SYS_SEND) || (defined(HAVE_DECL_SYS_SEND) && HAVE_DECL_SYS_SEND)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SEND) == (9), "SYS_SEND != 9");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SEND 9
#endif
#if defined(SYS_RECV) || (defined(HAVE_DECL_SYS_RECV) && HAVE_DECL_SYS_RECV)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_RECV) == (10), "SYS_RECV != 10");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_RECV 10
#endif
#if defined(SYS_SENDTO) || (defined(HAVE_DECL_SYS_SENDTO) && HAVE_DECL_SYS_SENDTO)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SENDTO) == (11), "SYS_SENDTO != 11");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SENDTO 11
#endif
#if defined(SYS_RECVFROM) || (defined(HAVE_DECL_SYS_RECVFROM) && HAVE_DECL_SYS_RECVFROM)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_RECVFROM) == (12), "SYS_RECVFROM != 12");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_RECVFROM 12
#endif
#if defined(SYS_SHUTDOWN) || (defined(HAVE_DECL_SYS_SHUTDOWN) && HAVE_DECL_SYS_SHUTDOWN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SHUTDOWN) == (13), "SYS_SHUTDOWN != 13");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SHUTDOWN 13
#endif
#if defined(SYS_SETSOCKOPT) || (defined(HAVE_DECL_SYS_SETSOCKOPT) && HAVE_DECL_SYS_SETSOCKOPT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SETSOCKOPT) == (14), "SYS_SETSOCKOPT != 14");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SETSOCKOPT 14
#endif
#if defined(SYS_GETSOCKOPT) || (defined(HAVE_DECL_SYS_GETSOCKOPT) && HAVE_DECL_SYS_GETSOCKOPT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_GETSOCKOPT) == (15), "SYS_GETSOCKOPT != 15");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_GETSOCKOPT 15
#endif
#if defined(SYS_SENDMSG) || (defined(HAVE_DECL_SYS_SENDMSG) && HAVE_DECL_SYS_SENDMSG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SENDMSG) == (16), "SYS_SENDMSG != 16");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SENDMSG 16
#endif
#if defined(SYS_RECVMSG) || (defined(HAVE_DECL_SYS_RECVMSG) && HAVE_DECL_SYS_RECVMSG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_RECVMSG) == (17), "SYS_RECVMSG != 17");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_RECVMSG 17
#endif
#if defined(SYS_ACCEPT4) || (defined(HAVE_DECL_SYS_ACCEPT4) && HAVE_DECL_SYS_ACCEPT4)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_ACCEPT4) == (18), "SYS_ACCEPT4 != 18");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_ACCEPT4 18
#endif
#if defined(SYS_RECVMMSG) || (defined(HAVE_DECL_SYS_RECVMMSG) && HAVE_DECL_SYS_RECVMMSG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_RECVMMSG) == (19), "SYS_RECVMMSG != 19");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_RECVMMSG 19
#endif
#if defined(SYS_SENDMMSG) || (defined(HAVE_DECL_SYS_SENDMMSG) && HAVE_DECL_SYS_SENDMMSG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SENDMMSG) == (20), "SYS_SENDMMSG != 20");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SENDMMSG 20
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat socketcalls in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data socketcalls_xdata[] = {
 [SYS_SOCKET] = XLAT(SYS_SOCKET),
 #define XLAT_VAL_0 ((unsigned) (SYS_SOCKET))
 #define XLAT_STR_0 STRINGIFY(SYS_SOCKET)
 [SYS_BIND] = XLAT(SYS_BIND),
 #define XLAT_VAL_1 ((unsigned) (SYS_BIND))
 #define XLAT_STR_1 STRINGIFY(SYS_BIND)
 [SYS_CONNECT] = XLAT(SYS_CONNECT),
 #define XLAT_VAL_2 ((unsigned) (SYS_CONNECT))
 #define XLAT_STR_2 STRINGIFY(SYS_CONNECT)
 [SYS_LISTEN] = XLAT(SYS_LISTEN),
 #define XLAT_VAL_3 ((unsigned) (SYS_LISTEN))
 #define XLAT_STR_3 STRINGIFY(SYS_LISTEN)
 [SYS_ACCEPT] = XLAT(SYS_ACCEPT),
 #define XLAT_VAL_4 ((unsigned) (SYS_ACCEPT))
 #define XLAT_STR_4 STRINGIFY(SYS_ACCEPT)
 [SYS_GETSOCKNAME] = XLAT(SYS_GETSOCKNAME),
 #define XLAT_VAL_5 ((unsigned) (SYS_GETSOCKNAME))
 #define XLAT_STR_5 STRINGIFY(SYS_GETSOCKNAME)
 [SYS_GETPEERNAME] = XLAT(SYS_GETPEERNAME),
 #define XLAT_VAL_6 ((unsigned) (SYS_GETPEERNAME))
 #define XLAT_STR_6 STRINGIFY(SYS_GETPEERNAME)
 [SYS_SOCKETPAIR] = XLAT(SYS_SOCKETPAIR),
 #define XLAT_VAL_7 ((unsigned) (SYS_SOCKETPAIR))
 #define XLAT_STR_7 STRINGIFY(SYS_SOCKETPAIR)
 [SYS_SEND] = XLAT(SYS_SEND),
 #define XLAT_VAL_8 ((unsigned) (SYS_SEND))
 #define XLAT_STR_8 STRINGIFY(SYS_SEND)
 [SYS_RECV] = XLAT(SYS_RECV),
 #define XLAT_VAL_9 ((unsigned) (SYS_RECV))
 #define XLAT_STR_9 STRINGIFY(SYS_RECV)
 [SYS_SENDTO] = XLAT(SYS_SENDTO),
 #define XLAT_VAL_10 ((unsigned) (SYS_SENDTO))
 #define XLAT_STR_10 STRINGIFY(SYS_SENDTO)
 [SYS_RECVFROM] = XLAT(SYS_RECVFROM),
 #define XLAT_VAL_11 ((unsigned) (SYS_RECVFROM))
 #define XLAT_STR_11 STRINGIFY(SYS_RECVFROM)
 [SYS_SHUTDOWN] = XLAT(SYS_SHUTDOWN),
 #define XLAT_VAL_12 ((unsigned) (SYS_SHUTDOWN))
 #define XLAT_STR_12 STRINGIFY(SYS_SHUTDOWN)
 [SYS_SETSOCKOPT] = XLAT(SYS_SETSOCKOPT),
 #define XLAT_VAL_13 ((unsigned) (SYS_SETSOCKOPT))
 #define XLAT_STR_13 STRINGIFY(SYS_SETSOCKOPT)
 [SYS_GETSOCKOPT] = XLAT(SYS_GETSOCKOPT),
 #define XLAT_VAL_14 ((unsigned) (SYS_GETSOCKOPT))
 #define XLAT_STR_14 STRINGIFY(SYS_GETSOCKOPT)
 [SYS_SENDMSG] = XLAT(SYS_SENDMSG),
 #define XLAT_VAL_15 ((unsigned) (SYS_SENDMSG))
 #define XLAT_STR_15 STRINGIFY(SYS_SENDMSG)
 [SYS_RECVMSG] = XLAT(SYS_RECVMSG),
 #define XLAT_VAL_16 ((unsigned) (SYS_RECVMSG))
 #define XLAT_STR_16 STRINGIFY(SYS_RECVMSG)
 [SYS_ACCEPT4] = XLAT(SYS_ACCEPT4),
 #define XLAT_VAL_17 ((unsigned) (SYS_ACCEPT4))
 #define XLAT_STR_17 STRINGIFY(SYS_ACCEPT4)
 [SYS_RECVMMSG] = XLAT(SYS_RECVMMSG),
 #define XLAT_VAL_18 ((unsigned) (SYS_RECVMMSG))
 #define XLAT_STR_18 STRINGIFY(SYS_RECVMMSG)
 [SYS_SENDMMSG] = XLAT(SYS_SENDMMSG),
 #define XLAT_VAL_19 ((unsigned) (SYS_SENDMMSG))
 #define XLAT_STR_19 STRINGIFY(SYS_SENDMMSG)
};
static
const struct xlat socketcalls[1] = { {
 .data = socketcalls_xdata,
 .size = ARRAY_SIZE(socketcalls_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
