/* Generated by ./src/xlat/gen.sh from ./src/xlat/kvm_exit_io.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(KVM_EXIT_IO_IN) || (defined(HAVE_DECL_KVM_EXIT_IO_IN) && HAVE_DECL_KVM_EXIT_IO_IN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KVM_EXIT_IO_IN) == (0), "KVM_EXIT_IO_IN != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KVM_EXIT_IO_IN 0
#endif
#if defined(KVM_EXIT_IO_OUT) || (defined(HAVE_DECL_KVM_EXIT_IO_OUT) && HAVE_DECL_KVM_EXIT_IO_OUT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((KVM_EXIT_IO_OUT) == (1), "KVM_EXIT_IO_OUT != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define KVM_EXIT_IO_OUT 1
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat kvm_exit_io in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data kvm_exit_io_xdata[] = {
 [KVM_EXIT_IO_IN] = XLAT(KVM_EXIT_IO_IN),
 #define XLAT_VAL_0 ((unsigned) (KVM_EXIT_IO_IN))
 #define XLAT_STR_0 STRINGIFY(KVM_EXIT_IO_IN)
 [KVM_EXIT_IO_OUT] = XLAT(KVM_EXIT_IO_OUT),
 #define XLAT_VAL_1 ((unsigned) (KVM_EXIT_IO_OUT))
 #define XLAT_STR_1 STRINGIFY(KVM_EXIT_IO_OUT)
};
static
const struct xlat kvm_exit_io[1] = { {
 .data = kvm_exit_io_xdata,
 .size = ARRAY_SIZE(kvm_exit_io_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
