/* Generated by ./src/xlat/gen.sh from ./src/xlat/sock_shutdown_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(RCV_SHUTDOWN) || (defined(HAVE_DECL_RCV_SHUTDOWN) && HAVE_DECL_RCV_SHUTDOWN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RCV_SHUTDOWN) == (1), "RCV_SHUTDOWN != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RCV_SHUTDOWN 1
#endif
#if defined(SEND_SHUTDOWN) || (defined(HAVE_DECL_SEND_SHUTDOWN) && HAVE_DECL_SEND_SHUTDOWN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SEND_SHUTDOWN) == (2), "SEND_SHUTDOWN != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SEND_SHUTDOWN 2
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sock_shutdown_flags_xdata[] = {
 XLAT(RCV_SHUTDOWN),
 #define XLAT_VAL_0 ((unsigned) (RCV_SHUTDOWN))
 #define XLAT_STR_0 STRINGIFY(RCV_SHUTDOWN)
 XLAT(SEND_SHUTDOWN),
 #define XLAT_VAL_1 ((unsigned) (SEND_SHUTDOWN))
 #define XLAT_STR_1 STRINGIFY(SEND_SHUTDOWN)
};
const struct xlat sock_shutdown_flags[1] = { {
 .data = sock_shutdown_flags_xdata,
 .size = ARRAY_SIZE(sock_shutdown_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
