/* Generated by ./src/xlat/gen.sh from ./src/xlat/statmount_mask.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat statmount_mask in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data statmount_mask_xdata[] = {
 XLAT(STATMOUNT_SB_BASIC),
 #define XLAT_VAL_0 ((unsigned) (STATMOUNT_SB_BASIC))
 #define XLAT_STR_0 STRINGIFY(STATMOUNT_SB_BASIC)
 XLAT(STATMOUNT_MNT_BASIC),
 #define XLAT_VAL_1 ((unsigned) (STATMOUNT_MNT_BASIC))
 #define XLAT_STR_1 STRINGIFY(STATMOUNT_MNT_BASIC)
 XLAT(STATMOUNT_PROPAGATE_FROM),
 #define XLAT_VAL_2 ((unsigned) (STATMOUNT_PROPAGATE_FROM))
 #define XLAT_STR_2 STRINGIFY(STATMOUNT_PROPAGATE_FROM)
 XLAT(STATMOUNT_MNT_ROOT),
 #define XLAT_VAL_3 ((unsigned) (STATMOUNT_MNT_ROOT))
 #define XLAT_STR_3 STRINGIFY(STATMOUNT_MNT_ROOT)
 XLAT(STATMOUNT_MNT_POINT),
 #define XLAT_VAL_4 ((unsigned) (STATMOUNT_MNT_POINT))
 #define XLAT_STR_4 STRINGIFY(STATMOUNT_MNT_POINT)
 XLAT(STATMOUNT_FS_TYPE),
 #define XLAT_VAL_5 ((unsigned) (STATMOUNT_FS_TYPE))
 #define XLAT_STR_5 STRINGIFY(STATMOUNT_FS_TYPE)
 XLAT(STATMOUNT_MNT_NS_ID),
 #define XLAT_VAL_6 ((unsigned) (STATMOUNT_MNT_NS_ID))
 #define XLAT_STR_6 STRINGIFY(STATMOUNT_MNT_NS_ID)
 XLAT(STATMOUNT_MNT_OPTS),
 #define XLAT_VAL_7 ((unsigned) (STATMOUNT_MNT_OPTS))
 #define XLAT_STR_7 STRINGIFY(STATMOUNT_MNT_OPTS)
 XLAT(STATMOUNT_FS_SUBTYPE),
 #define XLAT_VAL_8 ((unsigned) (STATMOUNT_FS_SUBTYPE))
 #define XLAT_STR_8 STRINGIFY(STATMOUNT_FS_SUBTYPE)
 XLAT(STATMOUNT_SB_SOURCE),
 #define XLAT_VAL_9 ((unsigned) (STATMOUNT_SB_SOURCE))
 #define XLAT_STR_9 STRINGIFY(STATMOUNT_SB_SOURCE)
 XLAT(STATMOUNT_OPT_ARRAY),
 #define XLAT_VAL_10 ((unsigned) (STATMOUNT_OPT_ARRAY))
 #define XLAT_STR_10 STRINGIFY(STATMOUNT_OPT_ARRAY)
 XLAT(STATMOUNT_OPT_SEC_ARRAY),
 #define XLAT_VAL_11 ((unsigned) (STATMOUNT_OPT_SEC_ARRAY))
 #define XLAT_STR_11 STRINGIFY(STATMOUNT_OPT_SEC_ARRAY)
 XLAT(STATMOUNT_SUPPORTED_MASK),
 #define XLAT_VAL_12 ((unsigned) (STATMOUNT_SUPPORTED_MASK))
 #define XLAT_STR_12 STRINGIFY(STATMOUNT_SUPPORTED_MASK)
 XLAT(STATMOUNT_MNT_UIDMAP),
 #define XLAT_VAL_13 ((unsigned) (STATMOUNT_MNT_UIDMAP))
 #define XLAT_STR_13 STRINGIFY(STATMOUNT_MNT_UIDMAP)
 XLAT(STATMOUNT_MNT_GIDMAP),
 #define XLAT_VAL_14 ((unsigned) (STATMOUNT_MNT_GIDMAP))
 #define XLAT_STR_14 STRINGIFY(STATMOUNT_MNT_GIDMAP)
};
static
const struct xlat statmount_mask[1] = { {
 .data = statmount_mask_xdata,
 .size = ARRAY_SIZE(statmount_mask_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
