/* Generated by ./src/xlat/gen.sh from ./src/xlat/syslog_action_type.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(SYSLOG_ACTION_CLOSE) || (defined(HAVE_DECL_SYSLOG_ACTION_CLOSE) && HAVE_DECL_SYSLOG_ACTION_CLOSE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_CLOSE) == (0), "SYSLOG_ACTION_CLOSE != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_CLOSE 0
#endif
#if defined(SYSLOG_ACTION_OPEN) || (defined(HAVE_DECL_SYSLOG_ACTION_OPEN) && HAVE_DECL_SYSLOG_ACTION_OPEN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_OPEN) == (1), "SYSLOG_ACTION_OPEN != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_OPEN 1
#endif
#if defined(SYSLOG_ACTION_READ) || (defined(HAVE_DECL_SYSLOG_ACTION_READ) && HAVE_DECL_SYSLOG_ACTION_READ)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_READ) == (2), "SYSLOG_ACTION_READ != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_READ 2
#endif
#if defined(SYSLOG_ACTION_READ_ALL) || (defined(HAVE_DECL_SYSLOG_ACTION_READ_ALL) && HAVE_DECL_SYSLOG_ACTION_READ_ALL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_READ_ALL) == (3), "SYSLOG_ACTION_READ_ALL != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_READ_ALL 3
#endif
#if defined(SYSLOG_ACTION_READ_CLEAR) || (defined(HAVE_DECL_SYSLOG_ACTION_READ_CLEAR) && HAVE_DECL_SYSLOG_ACTION_READ_CLEAR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_READ_CLEAR) == (4), "SYSLOG_ACTION_READ_CLEAR != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_READ_CLEAR 4
#endif
#if defined(SYSLOG_ACTION_CLEAR) || (defined(HAVE_DECL_SYSLOG_ACTION_CLEAR) && HAVE_DECL_SYSLOG_ACTION_CLEAR)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_CLEAR) == (5), "SYSLOG_ACTION_CLEAR != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_CLEAR 5
#endif
#if defined(SYSLOG_ACTION_CONSOLE_OFF) || (defined(HAVE_DECL_SYSLOG_ACTION_CONSOLE_OFF) && HAVE_DECL_SYSLOG_ACTION_CONSOLE_OFF)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_CONSOLE_OFF) == (6), "SYSLOG_ACTION_CONSOLE_OFF != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_CONSOLE_OFF 6
#endif
#if defined(SYSLOG_ACTION_CONSOLE_ON) || (defined(HAVE_DECL_SYSLOG_ACTION_CONSOLE_ON) && HAVE_DECL_SYSLOG_ACTION_CONSOLE_ON)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_CONSOLE_ON) == (7), "SYSLOG_ACTION_CONSOLE_ON != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_CONSOLE_ON 7
#endif
#if defined(SYSLOG_ACTION_CONSOLE_LEVEL) || (defined(HAVE_DECL_SYSLOG_ACTION_CONSOLE_LEVEL) && HAVE_DECL_SYSLOG_ACTION_CONSOLE_LEVEL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_CONSOLE_LEVEL) == (8), "SYSLOG_ACTION_CONSOLE_LEVEL != 8");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_CONSOLE_LEVEL 8
#endif
#if defined(SYSLOG_ACTION_SIZE_UNREAD) || (defined(HAVE_DECL_SYSLOG_ACTION_SIZE_UNREAD) && HAVE_DECL_SYSLOG_ACTION_SIZE_UNREAD)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_SIZE_UNREAD) == (9), "SYSLOG_ACTION_SIZE_UNREAD != 9");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_SIZE_UNREAD 9
#endif
#if defined(SYSLOG_ACTION_SIZE_BUFFER) || (defined(HAVE_DECL_SYSLOG_ACTION_SIZE_BUFFER) && HAVE_DECL_SYSLOG_ACTION_SIZE_BUFFER)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYSLOG_ACTION_SIZE_BUFFER) == (10), "SYSLOG_ACTION_SIZE_BUFFER != 10");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYSLOG_ACTION_SIZE_BUFFER 10
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat syslog_action_type in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data syslog_action_type_xdata[] = {
 [SYSLOG_ACTION_CLOSE] = XLAT(SYSLOG_ACTION_CLOSE),
 #define XLAT_VAL_0 ((unsigned) (SYSLOG_ACTION_CLOSE))
 #define XLAT_STR_0 STRINGIFY(SYSLOG_ACTION_CLOSE)
 [SYSLOG_ACTION_OPEN] = XLAT(SYSLOG_ACTION_OPEN),
 #define XLAT_VAL_1 ((unsigned) (SYSLOG_ACTION_OPEN))
 #define XLAT_STR_1 STRINGIFY(SYSLOG_ACTION_OPEN)
 [SYSLOG_ACTION_READ] = XLAT(SYSLOG_ACTION_READ),
 #define XLAT_VAL_2 ((unsigned) (SYSLOG_ACTION_READ))
 #define XLAT_STR_2 STRINGIFY(SYSLOG_ACTION_READ)
 [SYSLOG_ACTION_READ_ALL] = XLAT(SYSLOG_ACTION_READ_ALL),
 #define XLAT_VAL_3 ((unsigned) (SYSLOG_ACTION_READ_ALL))
 #define XLAT_STR_3 STRINGIFY(SYSLOG_ACTION_READ_ALL)
 [SYSLOG_ACTION_READ_CLEAR] = XLAT(SYSLOG_ACTION_READ_CLEAR),
 #define XLAT_VAL_4 ((unsigned) (SYSLOG_ACTION_READ_CLEAR))
 #define XLAT_STR_4 STRINGIFY(SYSLOG_ACTION_READ_CLEAR)
 [SYSLOG_ACTION_CLEAR] = XLAT(SYSLOG_ACTION_CLEAR),
 #define XLAT_VAL_5 ((unsigned) (SYSLOG_ACTION_CLEAR))
 #define XLAT_STR_5 STRINGIFY(SYSLOG_ACTION_CLEAR)
 [SYSLOG_ACTION_CONSOLE_OFF] = XLAT(SYSLOG_ACTION_CONSOLE_OFF),
 #define XLAT_VAL_6 ((unsigned) (SYSLOG_ACTION_CONSOLE_OFF))
 #define XLAT_STR_6 STRINGIFY(SYSLOG_ACTION_CONSOLE_OFF)
 [SYSLOG_ACTION_CONSOLE_ON] = XLAT(SYSLOG_ACTION_CONSOLE_ON),
 #define XLAT_VAL_7 ((unsigned) (SYSLOG_ACTION_CONSOLE_ON))
 #define XLAT_STR_7 STRINGIFY(SYSLOG_ACTION_CONSOLE_ON)
 [SYSLOG_ACTION_CONSOLE_LEVEL] = XLAT(SYSLOG_ACTION_CONSOLE_LEVEL),
 #define XLAT_VAL_8 ((unsigned) (SYSLOG_ACTION_CONSOLE_LEVEL))
 #define XLAT_STR_8 STRINGIFY(SYSLOG_ACTION_CONSOLE_LEVEL)
 [SYSLOG_ACTION_SIZE_UNREAD] = XLAT(SYSLOG_ACTION_SIZE_UNREAD),
 #define XLAT_VAL_9 ((unsigned) (SYSLOG_ACTION_SIZE_UNREAD))
 #define XLAT_STR_9 STRINGIFY(SYSLOG_ACTION_SIZE_UNREAD)
 [SYSLOG_ACTION_SIZE_BUFFER] = XLAT(SYSLOG_ACTION_SIZE_BUFFER),
 #define XLAT_VAL_10 ((unsigned) (SYSLOG_ACTION_SIZE_BUFFER))
 #define XLAT_STR_10 STRINGIFY(SYSLOG_ACTION_SIZE_BUFFER)
};
static
const struct xlat syslog_action_type[1] = { {
 .data = syslog_action_type_xdata,
 .size = ARRAY_SIZE(syslog_action_type_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
