/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_ifla_xdp_attached_mode.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_ifla_xdp_attached_mode in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_ifla_xdp_attached_mode_xdata[] = {
 [XDP_ATTACHED_NONE] = XLAT(XDP_ATTACHED_NONE),
 #define XLAT_VAL_0 ((unsigned) (XDP_ATTACHED_NONE))
 #define XLAT_STR_0 STRINGIFY(XDP_ATTACHED_NONE)
 [XDP_ATTACHED_DRV] = XLAT(XDP_ATTACHED_DRV),
 #define XLAT_VAL_1 ((unsigned) (XDP_ATTACHED_DRV))
 #define XLAT_STR_1 STRINGIFY(XDP_ATTACHED_DRV)
 [XDP_ATTACHED_SKB] = XLAT(XDP_ATTACHED_SKB),
 #define XLAT_VAL_2 ((unsigned) (XDP_ATTACHED_SKB))
 #define XLAT_STR_2 STRINGIFY(XDP_ATTACHED_SKB)
 [XDP_ATTACHED_HW] = XLAT(XDP_ATTACHED_HW),
 #define XLAT_VAL_3 ((unsigned) (XDP_ATTACHED_HW))
 #define XLAT_STR_3 STRINGIFY(XDP_ATTACHED_HW)
 [XDP_ATTACHED_MULTI] = XLAT(XDP_ATTACHED_MULTI),
 #define XLAT_VAL_4 ((unsigned) (XDP_ATTACHED_MULTI))
 #define XLAT_STR_4 STRINGIFY(XDP_ATTACHED_MULTI)
};
static
const struct xlat rtnl_ifla_xdp_attached_mode[1] = { {
 .data = rtnl_ifla_xdp_attached_mode_xdata,
 .size = ARRAY_SIZE(rtnl_ifla_xdp_attached_mode_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
