#include <stdint.h>
typedef
struct {
uint32_t gr_interface;
struct {
uint16_t ss_family;
char __ss_padding[122];
uint32_t __ss_align;
} ATTRIBUTE_PACKED gr_group;
} ATTRIBUTE_PACKED mx32_struct_group_req;
#define MPERS_mx32_struct_group_req mx32_struct_group_req
