/* Generated by ./src/xlat/gen.sh from ./src/xlat/tcp_state_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data tcp_state_flags_xdata[] = {

#if defined(TCP_ESTABLISHED) || (defined(HAVE_DECL_TCP_ESTABLISHED) && HAVE_DECL_TCP_ESTABLISHED)
  XLAT_PAIR(1ULL<<TCP_ESTABLISHED, "1<<TCP_ESTABLISHED"),
 #define XLAT_VAL_0 ((unsigned) (1ULL<<TCP_ESTABLISHED))
 #define XLAT_STR_0 "1<<TCP_ESTABLISHED"
#endif
#if defined(TCP_SYN_SENT) || (defined(HAVE_DECL_TCP_SYN_SENT) && HAVE_DECL_TCP_SYN_SENT)
  XLAT_PAIR(1ULL<<TCP_SYN_SENT, "1<<TCP_SYN_SENT"),
 #define XLAT_VAL_1 ((unsigned) (1ULL<<TCP_SYN_SENT))
 #define XLAT_STR_1 "1<<TCP_SYN_SENT"
#endif
#if defined(TCP_SYN_RECV) || (defined(HAVE_DECL_TCP_SYN_RECV) && HAVE_DECL_TCP_SYN_RECV)
  XLAT_PAIR(1ULL<<TCP_SYN_RECV, "1<<TCP_SYN_RECV"),
 #define XLAT_VAL_2 ((unsigned) (1ULL<<TCP_SYN_RECV))
 #define XLAT_STR_2 "1<<TCP_SYN_RECV"
#endif
#if defined(TCP_FIN_WAIT1) || (defined(HAVE_DECL_TCP_FIN_WAIT1) && HAVE_DECL_TCP_FIN_WAIT1)
  XLAT_PAIR(1ULL<<TCP_FIN_WAIT1, "1<<TCP_FIN_WAIT1"),
 #define XLAT_VAL_3 ((unsigned) (1ULL<<TCP_FIN_WAIT1))
 #define XLAT_STR_3 "1<<TCP_FIN_WAIT1"
#endif
#if defined(TCP_FIN_WAIT2) || (defined(HAVE_DECL_TCP_FIN_WAIT2) && HAVE_DECL_TCP_FIN_WAIT2)
  XLAT_PAIR(1ULL<<TCP_FIN_WAIT2, "1<<TCP_FIN_WAIT2"),
 #define XLAT_VAL_4 ((unsigned) (1ULL<<TCP_FIN_WAIT2))
 #define XLAT_STR_4 "1<<TCP_FIN_WAIT2"
#endif
#if defined(TCP_TIME_WAIT) || (defined(HAVE_DECL_TCP_TIME_WAIT) && HAVE_DECL_TCP_TIME_WAIT)
  XLAT_PAIR(1ULL<<TCP_TIME_WAIT, "1<<TCP_TIME_WAIT"),
 #define XLAT_VAL_5 ((unsigned) (1ULL<<TCP_TIME_WAIT))
 #define XLAT_STR_5 "1<<TCP_TIME_WAIT"
#endif
#if defined(TCP_CLOSE) || (defined(HAVE_DECL_TCP_CLOSE) && HAVE_DECL_TCP_CLOSE)
  XLAT_PAIR(1ULL<<TCP_CLOSE, "1<<TCP_CLOSE"),
 #define XLAT_VAL_6 ((unsigned) (1ULL<<TCP_CLOSE))
 #define XLAT_STR_6 "1<<TCP_CLOSE"
#endif
#if defined(TCP_CLOSE_WAIT) || (defined(HAVE_DECL_TCP_CLOSE_WAIT) && HAVE_DECL_TCP_CLOSE_WAIT)
  XLAT_PAIR(1ULL<<TCP_CLOSE_WAIT, "1<<TCP_CLOSE_WAIT"),
 #define XLAT_VAL_7 ((unsigned) (1ULL<<TCP_CLOSE_WAIT))
 #define XLAT_STR_7 "1<<TCP_CLOSE_WAIT"
#endif
#if defined(TCP_LAST_ACK) || (defined(HAVE_DECL_TCP_LAST_ACK) && HAVE_DECL_TCP_LAST_ACK)
  XLAT_PAIR(1ULL<<TCP_LAST_ACK, "1<<TCP_LAST_ACK"),
 #define XLAT_VAL_8 ((unsigned) (1ULL<<TCP_LAST_ACK))
 #define XLAT_STR_8 "1<<TCP_LAST_ACK"
#endif
#if defined(TCP_LISTEN) || (defined(HAVE_DECL_TCP_LISTEN) && HAVE_DECL_TCP_LISTEN)
  XLAT_PAIR(1ULL<<TCP_LISTEN, "1<<TCP_LISTEN"),
 #define XLAT_VAL_9 ((unsigned) (1ULL<<TCP_LISTEN))
 #define XLAT_STR_9 "1<<TCP_LISTEN"
#endif
#if defined(TCP_CLOSING) || (defined(HAVE_DECL_TCP_CLOSING) && HAVE_DECL_TCP_CLOSING)
  XLAT_PAIR(1ULL<<TCP_CLOSING, "1<<TCP_CLOSING"),
 #define XLAT_VAL_10 ((unsigned) (1ULL<<TCP_CLOSING))
 #define XLAT_STR_10 "1<<TCP_CLOSING"
#endif
#if defined(TCP_NEW_SYN_RECV) || (defined(HAVE_DECL_TCP_NEW_SYN_RECV) && HAVE_DECL_TCP_NEW_SYN_RECV)
  XLAT_PAIR(1ULL<<TCP_NEW_SYN_RECV, "1<<TCP_NEW_SYN_RECV"),
 #define XLAT_VAL_11 ((unsigned) (1ULL<<TCP_NEW_SYN_RECV))
 #define XLAT_STR_11 "1<<TCP_NEW_SYN_RECV"
#endif
#if defined(TCP_BOUND_INACTIVE) || (defined(HAVE_DECL_TCP_BOUND_INACTIVE) && HAVE_DECL_TCP_BOUND_INACTIVE)
  XLAT_PAIR(1ULL<<TCP_BOUND_INACTIVE, "1<<TCP_BOUND_INACTIVE"),
 #define XLAT_VAL_12 ((unsigned) (1ULL<<TCP_BOUND_INACTIVE))
 #define XLAT_STR_12 "1<<TCP_BOUND_INACTIVE"
#endif
};
const struct xlat tcp_state_flags[1] = { {
 .data = tcp_state_flags_xdata,
 .size = ARRAY_SIZE(tcp_state_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
