/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_neightbl_parms_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(NDTPA_UNSPEC) || (defined(HAVE_DECL_NDTPA_UNSPEC) && HAVE_DECL_NDTPA_UNSPEC)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_UNSPEC) == (0), "NDTPA_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_UNSPEC 0
#endif
#if defined(NDTPA_IFINDEX) || (defined(HAVE_DECL_NDTPA_IFINDEX) && HAVE_DECL_NDTPA_IFINDEX)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_IFINDEX) == (1), "NDTPA_IFINDEX != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_IFINDEX 1
#endif
#if defined(NDTPA_REFCNT) || (defined(HAVE_DECL_NDTPA_REFCNT) && HAVE_DECL_NDTPA_REFCNT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_REFCNT) == (2), "NDTPA_REFCNT != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_REFCNT 2
#endif
#if defined(NDTPA_REACHABLE_TIME) || (defined(HAVE_DECL_NDTPA_REACHABLE_TIME) && HAVE_DECL_NDTPA_REACHABLE_TIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_REACHABLE_TIME) == (3), "NDTPA_REACHABLE_TIME != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_REACHABLE_TIME 3
#endif
#if defined(NDTPA_BASE_REACHABLE_TIME) || (defined(HAVE_DECL_NDTPA_BASE_REACHABLE_TIME) && HAVE_DECL_NDTPA_BASE_REACHABLE_TIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_BASE_REACHABLE_TIME) == (4), "NDTPA_BASE_REACHABLE_TIME != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_BASE_REACHABLE_TIME 4
#endif
#if defined(NDTPA_RETRANS_TIME) || (defined(HAVE_DECL_NDTPA_RETRANS_TIME) && HAVE_DECL_NDTPA_RETRANS_TIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_RETRANS_TIME) == (5), "NDTPA_RETRANS_TIME != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_RETRANS_TIME 5
#endif
#if defined(NDTPA_GC_STALETIME) || (defined(HAVE_DECL_NDTPA_GC_STALETIME) && HAVE_DECL_NDTPA_GC_STALETIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_GC_STALETIME) == (6), "NDTPA_GC_STALETIME != 6");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_GC_STALETIME 6
#endif
#if defined(NDTPA_DELAY_PROBE_TIME) || (defined(HAVE_DECL_NDTPA_DELAY_PROBE_TIME) && HAVE_DECL_NDTPA_DELAY_PROBE_TIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_DELAY_PROBE_TIME) == (7), "NDTPA_DELAY_PROBE_TIME != 7");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_DELAY_PROBE_TIME 7
#endif
#if defined(NDTPA_QUEUE_LEN) || (defined(HAVE_DECL_NDTPA_QUEUE_LEN) && HAVE_DECL_NDTPA_QUEUE_LEN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_QUEUE_LEN) == (8), "NDTPA_QUEUE_LEN != 8");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_QUEUE_LEN 8
#endif
#if defined(NDTPA_APP_PROBES) || (defined(HAVE_DECL_NDTPA_APP_PROBES) && HAVE_DECL_NDTPA_APP_PROBES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_APP_PROBES) == (9), "NDTPA_APP_PROBES != 9");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_APP_PROBES 9
#endif
#if defined(NDTPA_UCAST_PROBES) || (defined(HAVE_DECL_NDTPA_UCAST_PROBES) && HAVE_DECL_NDTPA_UCAST_PROBES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_UCAST_PROBES) == (10), "NDTPA_UCAST_PROBES != 10");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_UCAST_PROBES 10
#endif
#if defined(NDTPA_MCAST_PROBES) || (defined(HAVE_DECL_NDTPA_MCAST_PROBES) && HAVE_DECL_NDTPA_MCAST_PROBES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_MCAST_PROBES) == (11), "NDTPA_MCAST_PROBES != 11");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_MCAST_PROBES 11
#endif
#if defined(NDTPA_ANYCAST_DELAY) || (defined(HAVE_DECL_NDTPA_ANYCAST_DELAY) && HAVE_DECL_NDTPA_ANYCAST_DELAY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_ANYCAST_DELAY) == (12), "NDTPA_ANYCAST_DELAY != 12");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_ANYCAST_DELAY 12
#endif
#if defined(NDTPA_PROXY_DELAY) || (defined(HAVE_DECL_NDTPA_PROXY_DELAY) && HAVE_DECL_NDTPA_PROXY_DELAY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_PROXY_DELAY) == (13), "NDTPA_PROXY_DELAY != 13");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_PROXY_DELAY 13
#endif
#if defined(NDTPA_PROXY_QLEN) || (defined(HAVE_DECL_NDTPA_PROXY_QLEN) && HAVE_DECL_NDTPA_PROXY_QLEN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_PROXY_QLEN) == (14), "NDTPA_PROXY_QLEN != 14");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_PROXY_QLEN 14
#endif
#if defined(NDTPA_LOCKTIME) || (defined(HAVE_DECL_NDTPA_LOCKTIME) && HAVE_DECL_NDTPA_LOCKTIME)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_LOCKTIME) == (15), "NDTPA_LOCKTIME != 15");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_LOCKTIME 15
#endif
#if defined(NDTPA_QUEUE_LENBYTES) || (defined(HAVE_DECL_NDTPA_QUEUE_LENBYTES) && HAVE_DECL_NDTPA_QUEUE_LENBYTES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_QUEUE_LENBYTES) == (16), "NDTPA_QUEUE_LENBYTES != 16");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_QUEUE_LENBYTES 16
#endif
#if defined(NDTPA_MCAST_REPROBES) || (defined(HAVE_DECL_NDTPA_MCAST_REPROBES) && HAVE_DECL_NDTPA_MCAST_REPROBES)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_MCAST_REPROBES) == (17), "NDTPA_MCAST_REPROBES != 17");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_MCAST_REPROBES 17
#endif
#if defined(NDTPA_PAD) || (defined(HAVE_DECL_NDTPA_PAD) && HAVE_DECL_NDTPA_PAD)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_PAD) == (18), "NDTPA_PAD != 18");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_PAD 18
#endif
#if defined(NDTPA_INTERVAL_PROBE_TIME_MS) || (defined(HAVE_DECL_NDTPA_INTERVAL_PROBE_TIME_MS) && HAVE_DECL_NDTPA_INTERVAL_PROBE_TIME_MS)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NDTPA_INTERVAL_PROBE_TIME_MS) == (19), "NDTPA_INTERVAL_PROBE_TIME_MS != 19");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NDTPA_INTERVAL_PROBE_TIME_MS 19
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_neightbl_parms_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_neightbl_parms_attrs_xdata[] = {
 [NDTPA_UNSPEC] = XLAT(NDTPA_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (NDTPA_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(NDTPA_UNSPEC)
 [NDTPA_IFINDEX] = XLAT(NDTPA_IFINDEX),
 #define XLAT_VAL_1 ((unsigned) (NDTPA_IFINDEX))
 #define XLAT_STR_1 STRINGIFY(NDTPA_IFINDEX)
 [NDTPA_REFCNT] = XLAT(NDTPA_REFCNT),
 #define XLAT_VAL_2 ((unsigned) (NDTPA_REFCNT))
 #define XLAT_STR_2 STRINGIFY(NDTPA_REFCNT)
 [NDTPA_REACHABLE_TIME] = XLAT(NDTPA_REACHABLE_TIME),
 #define XLAT_VAL_3 ((unsigned) (NDTPA_REACHABLE_TIME))
 #define XLAT_STR_3 STRINGIFY(NDTPA_REACHABLE_TIME)
 [NDTPA_BASE_REACHABLE_TIME] = XLAT(NDTPA_BASE_REACHABLE_TIME),
 #define XLAT_VAL_4 ((unsigned) (NDTPA_BASE_REACHABLE_TIME))
 #define XLAT_STR_4 STRINGIFY(NDTPA_BASE_REACHABLE_TIME)
 [NDTPA_RETRANS_TIME] = XLAT(NDTPA_RETRANS_TIME),
 #define XLAT_VAL_5 ((unsigned) (NDTPA_RETRANS_TIME))
 #define XLAT_STR_5 STRINGIFY(NDTPA_RETRANS_TIME)
 [NDTPA_GC_STALETIME] = XLAT(NDTPA_GC_STALETIME),
 #define XLAT_VAL_6 ((unsigned) (NDTPA_GC_STALETIME))
 #define XLAT_STR_6 STRINGIFY(NDTPA_GC_STALETIME)
 [NDTPA_DELAY_PROBE_TIME] = XLAT(NDTPA_DELAY_PROBE_TIME),
 #define XLAT_VAL_7 ((unsigned) (NDTPA_DELAY_PROBE_TIME))
 #define XLAT_STR_7 STRINGIFY(NDTPA_DELAY_PROBE_TIME)
 [NDTPA_QUEUE_LEN] = XLAT(NDTPA_QUEUE_LEN),
 #define XLAT_VAL_8 ((unsigned) (NDTPA_QUEUE_LEN))
 #define XLAT_STR_8 STRINGIFY(NDTPA_QUEUE_LEN)
 [NDTPA_APP_PROBES] = XLAT(NDTPA_APP_PROBES),
 #define XLAT_VAL_9 ((unsigned) (NDTPA_APP_PROBES))
 #define XLAT_STR_9 STRINGIFY(NDTPA_APP_PROBES)
 [NDTPA_UCAST_PROBES] = XLAT(NDTPA_UCAST_PROBES),
 #define XLAT_VAL_10 ((unsigned) (NDTPA_UCAST_PROBES))
 #define XLAT_STR_10 STRINGIFY(NDTPA_UCAST_PROBES)
 [NDTPA_MCAST_PROBES] = XLAT(NDTPA_MCAST_PROBES),
 #define XLAT_VAL_11 ((unsigned) (NDTPA_MCAST_PROBES))
 #define XLAT_STR_11 STRINGIFY(NDTPA_MCAST_PROBES)
 [NDTPA_ANYCAST_DELAY] = XLAT(NDTPA_ANYCAST_DELAY),
 #define XLAT_VAL_12 ((unsigned) (NDTPA_ANYCAST_DELAY))
 #define XLAT_STR_12 STRINGIFY(NDTPA_ANYCAST_DELAY)
 [NDTPA_PROXY_DELAY] = XLAT(NDTPA_PROXY_DELAY),
 #define XLAT_VAL_13 ((unsigned) (NDTPA_PROXY_DELAY))
 #define XLAT_STR_13 STRINGIFY(NDTPA_PROXY_DELAY)
 [NDTPA_PROXY_QLEN] = XLAT(NDTPA_PROXY_QLEN),
 #define XLAT_VAL_14 ((unsigned) (NDTPA_PROXY_QLEN))
 #define XLAT_STR_14 STRINGIFY(NDTPA_PROXY_QLEN)
 [NDTPA_LOCKTIME] = XLAT(NDTPA_LOCKTIME),
 #define XLAT_VAL_15 ((unsigned) (NDTPA_LOCKTIME))
 #define XLAT_STR_15 STRINGIFY(NDTPA_LOCKTIME)
 [NDTPA_QUEUE_LENBYTES] = XLAT(NDTPA_QUEUE_LENBYTES),
 #define XLAT_VAL_16 ((unsigned) (NDTPA_QUEUE_LENBYTES))
 #define XLAT_STR_16 STRINGIFY(NDTPA_QUEUE_LENBYTES)
 [NDTPA_MCAST_REPROBES] = XLAT(NDTPA_MCAST_REPROBES),
 #define XLAT_VAL_17 ((unsigned) (NDTPA_MCAST_REPROBES))
 #define XLAT_STR_17 STRINGIFY(NDTPA_MCAST_REPROBES)
 [NDTPA_PAD] = XLAT(NDTPA_PAD),
 #define XLAT_VAL_18 ((unsigned) (NDTPA_PAD))
 #define XLAT_STR_18 STRINGIFY(NDTPA_PAD)
 [NDTPA_INTERVAL_PROBE_TIME_MS] = XLAT(NDTPA_INTERVAL_PROBE_TIME_MS),
 #define XLAT_VAL_19 ((unsigned) (NDTPA_INTERVAL_PROBE_TIME_MS))
 #define XLAT_STR_19 STRINGIFY(NDTPA_INTERVAL_PROBE_TIME_MS)
};
static
const struct xlat rtnl_neightbl_parms_attrs[1] = { {
 .data = rtnl_neightbl_parms_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_neightbl_parms_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
