/* Generated by ./src/xlat/gen.sh from ./src/xlat/btrfs_dev_stats_values.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat btrfs_dev_stats_values[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data btrfs_dev_stats_values_xdata[] = {
 [BTRFS_DEV_STAT_WRITE_ERRS] = XLAT(BTRFS_DEV_STAT_WRITE_ERRS),
 #define XLAT_VAL_0 ((unsigned) (BTRFS_DEV_STAT_WRITE_ERRS))
 #define XLAT_STR_0 STRINGIFY(BTRFS_DEV_STAT_WRITE_ERRS)
 [BTRFS_DEV_STAT_READ_ERRS] = XLAT(BTRFS_DEV_STAT_READ_ERRS),
 #define XLAT_VAL_1 ((unsigned) (BTRFS_DEV_STAT_READ_ERRS))
 #define XLAT_STR_1 STRINGIFY(BTRFS_DEV_STAT_READ_ERRS)
 [BTRFS_DEV_STAT_FLUSH_ERRS] = XLAT(BTRFS_DEV_STAT_FLUSH_ERRS),
 #define XLAT_VAL_2 ((unsigned) (BTRFS_DEV_STAT_FLUSH_ERRS))
 #define XLAT_STR_2 STRINGIFY(BTRFS_DEV_STAT_FLUSH_ERRS)
 [BTRFS_DEV_STAT_CORRUPTION_ERRS] = XLAT(BTRFS_DEV_STAT_CORRUPTION_ERRS),
 #define XLAT_VAL_3 ((unsigned) (BTRFS_DEV_STAT_CORRUPTION_ERRS))
 #define XLAT_STR_3 STRINGIFY(BTRFS_DEV_STAT_CORRUPTION_ERRS)
 [BTRFS_DEV_STAT_GENERATION_ERRS] = XLAT(BTRFS_DEV_STAT_GENERATION_ERRS),
 #define XLAT_VAL_4 ((unsigned) (BTRFS_DEV_STAT_GENERATION_ERRS))
 #define XLAT_STR_4 STRINGIFY(BTRFS_DEV_STAT_GENERATION_ERRS)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat btrfs_dev_stats_values[1] = { {
 .data = btrfs_dev_stats_values_xdata,
 .size = ARRAY_SIZE(btrfs_dev_stats_values_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
