/* Generated by ./src/xlat/gen.sh from ./src/xlat/gpio_line_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat gpio_line_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data gpio_line_flags_xdata[] = {
 XLAT(GPIOLINE_FLAG_KERNEL),
 #define XLAT_VAL_0 ((unsigned) (GPIOLINE_FLAG_KERNEL))
 #define XLAT_STR_0 STRINGIFY(GPIOLINE_FLAG_KERNEL)
 XLAT(GPIOLINE_FLAG_IS_OUT),
 #define XLAT_VAL_1 ((unsigned) (GPIOLINE_FLAG_IS_OUT))
 #define XLAT_STR_1 STRINGIFY(GPIOLINE_FLAG_IS_OUT)
 XLAT(GPIOLINE_FLAG_ACTIVE_LOW),
 #define XLAT_VAL_2 ((unsigned) (GPIOLINE_FLAG_ACTIVE_LOW))
 #define XLAT_STR_2 STRINGIFY(GPIOLINE_FLAG_ACTIVE_LOW)
 XLAT(GPIOLINE_FLAG_OPEN_DRAIN),
 #define XLAT_VAL_3 ((unsigned) (GPIOLINE_FLAG_OPEN_DRAIN))
 #define XLAT_STR_3 STRINGIFY(GPIOLINE_FLAG_OPEN_DRAIN)
 XLAT(GPIOLINE_FLAG_OPEN_SOURCE),
 #define XLAT_VAL_4 ((unsigned) (GPIOLINE_FLAG_OPEN_SOURCE))
 #define XLAT_STR_4 STRINGIFY(GPIOLINE_FLAG_OPEN_SOURCE)
 XLAT(GPIOLINE_FLAG_BIAS_PULL_UP),
 #define XLAT_VAL_5 ((unsigned) (GPIOLINE_FLAG_BIAS_PULL_UP))
 #define XLAT_STR_5 STRINGIFY(GPIOLINE_FLAG_BIAS_PULL_UP)
 XLAT(GPIOLINE_FLAG_BIAS_PULL_DOWN),
 #define XLAT_VAL_6 ((unsigned) (GPIOLINE_FLAG_BIAS_PULL_DOWN))
 #define XLAT_STR_6 STRINGIFY(GPIOLINE_FLAG_BIAS_PULL_DOWN)
 XLAT(GPIOLINE_FLAG_BIAS_DISABLE),
 #define XLAT_VAL_7 ((unsigned) (GPIOLINE_FLAG_BIAS_DISABLE))
 #define XLAT_STR_7 STRINGIFY(GPIOLINE_FLAG_BIAS_DISABLE)
};
static
const struct xlat gpio_line_flags[1] = { {
 .data = gpio_line_flags_xdata,
 .size = ARRAY_SIZE(gpio_line_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
